CREATE TABLE hibernate_sequences (
  sequence_name VARCHAR2(200) NOT NULL,
  next_val INTEGER NOT NULL,
  PRIMARY KEY (sequence_name)
);


CREATE TABLE SBI_CHECKS (
	CHECK_ID INTEGER NOT NULL ,
	DESCR VARCHAR2 (160),
	LABEL VARCHAR2 (20) NOT NULL ,
	VALUE_TYPE_CD VARCHAR2 (20) NOT NULL ,
	VALUE_TYPE_ID INTEGER NOT NULL ,
	VALUE_1 VARCHAR2 (400),
	VALUE_2 VARCHAR2 (400),
	NAME VARCHAR2 (40) NOT NULL ,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
    CONSTRAINT XAK1SBI_CHECKS UNIQUE (LABEL, ORGANIZATION),
PRIMARY KEY (CHECK_ID)
);

CREATE TABLE SBI_DOMAINS (
	VALUE_ID INTEGER NOT NULL ,
	VALUE_CD VARCHAR2 (100),
	VALUE_NM VARCHAR2 (40),
	DOMAIN_CD VARCHAR2 (20),
	DOMAIN_NM VARCHAR2 (40),
	VALUE_DS VARCHAR2 (160),
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
    CONSTRAINT XAK1SBI_DOMAINS UNIQUE (VALUE_CD, DOMAIN_CD),
PRIMARY KEY (VALUE_ID)
);

CREATE TABLE SBI_ENGINES (
	ENGINE_ID INTEGER NOT NULL ,
	ENCRYPT SMALLINT,
	NAME VARCHAR2 (40) NOT NULL ,
	DESCR VARCHAR2 (160),
	MAIN_URL VARCHAR2 (400),
	SECN_URL VARCHAR2 (400),
	OBJ_UPL_DIR VARCHAR2 (400),
	OBJ_USE_DIR VARCHAR2 (400),
	DRIVER_NM VARCHAR2 (400),
	LABEL VARCHAR2 (40) NOT NULL ,
	ENGINE_TYPE INTEGER NOT NULL ,
	CLASS_NM VARCHAR2 (400),
	BIOBJ_TYPE INTEGER NOT NULL ,
	USE_DATASOURCE SMALLINT DEFAULT 0,
	USE_DATASET SMALLINT DEFAULT 0,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
    CONSTRAINT XAK1SBI_ENGINES UNIQUE (LABEL, ORGANIZATION),
PRIMARY KEY (ENGINE_ID)
);


CREATE TABLE SBI_EXT_ROLES (
	EXT_ROLE_ID NUMBER(38,0) CONSTRAINT "SYS_C0011867" NOT NULL ,
	NAME 					VARCHAR2 (100) NOT NULL,
	DESCR 					VARCHAR2 (160),
	CODE 					VARCHAR2 (20),
	ROLE_TYPE_CD 			VARCHAR2 (20) CONSTRAINT "SYS_C0011868" NOT NULL ,
	ROLE_TYPE_ID 			NUMBER(38,0) CONSTRAINT "SYS_C0011869" NOT NULL ,
	IS_PUBLIC				SMALLINT DEFAULT 0,
	USER_IN              	VARCHAR2(100) NOT NULL,
    USER_UP              	VARCHAR2(100),
    USER_DE              	VARCHAR2(100),
    TIME_IN              	TIMESTAMP NOT NULL,
    TIME_UP              	TIMESTAMP DEFAULT NULL,
    TIME_DE              	TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       	VARCHAR2(10),
    SBI_VERSION_UP       	VARCHAR2(10),
    SBI_VERSION_DE       	VARCHAR2(10),
    META_VERSION         	VARCHAR2(100),
    ORGANIZATION         	VARCHAR2(20),
	CONSTRAINT XAK1SBI_EXT_ROLES UNIQUE (NAME, ORGANIZATION),
PRIMARY KEY (EXT_ROLE_ID)
);


CREATE TABLE SBI_FUNC_ROLE (
	FUNCT_ID INTEGER NOT NULL ,
	STATE_ID INTEGER NOT NULL ,
	ROLE_ID INTEGER NOT NULL ,
	STATE_CD VARCHAR2 (20),
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
PRIMARY KEY (FUNCT_ID,STATE_ID,ROLE_ID)
);


CREATE TABLE SBI_FUNCTIONS (
	FUNCT_ID INTEGER NOT NULL ,
	FUNCT_TYPE_CD VARCHAR2 (20) NOT NULL ,
	PARENT_FUNCT_ID INTEGER,
	NAME VARCHAR2 (40),
	DESCR VARCHAR2 (160),
	PATH VARCHAR2 (400),
	CODE VARCHAR2 (40) NOT NULL ,
	PROG INTEGER NOT NULL ,
	FUNCT_TYPE_ID INTEGER NOT NULL ,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
CONSTRAINT XAK1SBI_FUNCTIONS UNIQUE (CODE, ORGANIZATION),
PRIMARY KEY (FUNCT_ID)
);


CREATE TABLE SBI_LOV (
	LOV_ID INTEGER NOT NULL ,
	DESCR VARCHAR2 (160),
	LABEL VARCHAR2 (20) NOT NULL ,
	INPUT_TYPE_CD VARCHAR2 (20) NOT NULL ,
	DEFAULT_VAL VARCHAR2 (40),
	LOV_PROVIDER CLOB ,
	INPUT_TYPE_ID INTEGER NOT NULL ,
	PROFILE_ATTR VARCHAR2 (20),
	NAME VARCHAR2 (40) NOT NULL ,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
    DATASET_ID			 INTEGER,
    CONSTRAINT XAK1SBI_LOV UNIQUE (LABEL, ORGANIZATION),
    CONSTRAINT XAK2SBI_LOV UNIQUE (NAME, ORGANIZATION),
PRIMARY KEY (LOV_ID)
);


CREATE TABLE SBI_OBJ_FUNC (
	BIOBJ_ID INTEGER NOT NULL ,
	FUNCT_ID INTEGER NOT NULL ,
	PROG INTEGER,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
PRIMARY KEY (BIOBJ_ID,FUNCT_ID)
);


CREATE TABLE SBI_OBJ_PAR (
	OBJ_PAR_ID INTEGER NOT NULL ,
	PAR_ID INTEGER NOT NULL ,
	BIOBJ_ID INTEGER NOT NULL ,
	LABEL VARCHAR2 (40) NOT NULL ,
	REQ_FL SMALLINT DEFAULT 0,
	MOD_FL SMALLINT DEFAULT 0,
	VIEW_FL SMALLINT DEFAULT 1,
	MULT_FL SMALLINT DEFAULT 0,
	PROG INTEGER NOT NULL ,
	PARURL_NM VARCHAR2 (20),
	PRIORITY INTEGER,
	COL_SPAN             INTEGER,
    THICK_PERC           INTEGER,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
PRIMARY KEY (OBJ_PAR_ID)
);


CREATE TABLE SBI_OBJ_STATE (
	BIOBJ_ID INTEGER NOT NULL ,
	STATE_ID INTEGER NOT NULL ,
	START_DT DATE NOT NULL ,
	END_DT DATE,
	NOTE VARCHAR2 (300),
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
PRIMARY KEY (BIOBJ_ID,STATE_ID,START_DT)
);


CREATE TABLE SBI_OBJECTS (
	BIOBJ_ID INTEGER NOT NULL ,
	ENGINE_ID INTEGER NOT NULL ,
	DESCR VARCHAR2 (400),
	LABEL VARCHAR2 (100) NOT NULL ,
	ENCRYPT SMALLINT,
	PATH VARCHAR2 (400),
	REL_NAME VARCHAR2 (400),
	STATE_ID INTEGER NOT NULL ,
	STATE_CD VARCHAR2 (20) NOT NULL ,
	BIOBJ_TYPE_CD VARCHAR2 (20) NOT NULL ,
	BIOBJ_TYPE_ID INTEGER NOT NULL ,
	SCHED_FL SMALLINT,
	EXEC_MODE_ID INTEGER,
	STATE_CONS_ID INTEGER,
	EXEC_MODE_CD VARCHAR2 (20),
	STATE_CONS_CD VARCHAR2 (20),
	NAME VARCHAR2 (200) NOT NULL ,
	VISIBLE SMALLINT NOT NULL ,
	UUID VARCHAR2 (40) NOT NULL ,
	DATA_SOURCE_ID INTEGER,
	CREATION_DATE TIMESTAMP(6) NOT NULL ,
	CREATION_USER VARCHAR2 (45) NOT NULL ,
	REFRESH_SECONDS INTEGER DEFAULT 0,
	PROF_VISIBILITY VARCHAR2 (400),
	PREVIEW_FILE VARCHAR2(100) NULL,
	PARAMETERS_REGION    VARCHAR2(20) NULL,
	LOCKED_BY_USER        VARCHAR2(100) NULL,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
    CONSTRAINT XAK1SBI_OBJECTS UNIQUE (LABEL, ORGANIZATION),
    CONSTRAINT XAK2SBI_OBJECTS UNIQUE (NAME, ORGANIZATION),
PRIMARY KEY (BIOBJ_ID)
);


CREATE TABLE SBI_OBJECTS_RATING (
	USER_ID VARCHAR2 (127) NOT NULL ,
	OBJ_ID INTEGER NOT NULL ,
	RATING INTEGER NOT NULL ,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
PRIMARY KEY (USER_ID,OBJ_ID)
);


CREATE TABLE SBI_PARAMETERS (
	PAR_ID INTEGER NOT NULL ,
	DESCR VARCHAR2 (160),
	LENGTH SMALLINT NOT NULL ,
	LABEL VARCHAR2 (20) NOT NULL ,
	PAR_TYPE_CD VARCHAR2 (20) NOT NULL ,
	MASK VARCHAR2 (20),
	PAR_TYPE_ID INTEGER NOT NULL ,
	NAME VARCHAR2 (40) NOT NULL ,
	FUNCTIONAL_FLAG SMALLINT DEFAULT 1 NOT NULL ,
	TEMPORAL_FLAG SMALLINT DEFAULT 0 NOT NULL ,
	VALUE_SELECTION 		VARCHAR(20),
	SELECTED_LAYER 			VARCHAR(100),
	SELECTED_LAYER_PROP 	VARCHAR(40),
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
    CONSTRAINT XAK1SBI_PARAMETERS UNIQUE (LABEL, ORGANIZATION),
    CONSTRAINT XAK2SBI_PARAMETERS UNIQUE (NAME, ORGANIZATION),
PRIMARY KEY (PAR_ID)
);


CREATE TABLE SBI_PARUSE (
	USE_ID INTEGER NOT NULL ,
	LOV_ID INTEGER,
	DEFAULT_LOV_ID INTEGER,
  MAX_LOV_ID INTEGER,
	DEFAULT_FORMULA VARCHAR2(4000) NULL,
	LABEL VARCHAR2 (20) NOT NULL ,
	DESCR VARCHAR2 (160),
	PAR_ID INTEGER NOT NULL ,
	NAME VARCHAR2 (40) NOT NULL ,
	MAN_IN INTEGER NOT NULL ,
	MAXIMIZER_ENABLED	SMALLINT DEFAULT 0,
	SELECTION_TYPE VARCHAR2 (20) DEFAULT 'LIST',
	MULTIVALUE_FLAG INTEGER DEFAULT 0,
	VALUE_SELECTION 		VARCHAR(20),
    SELECTED_LAYER 			VARCHAR(100),
    SELECTED_LAYER_PROP 	VARCHAR(40),
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
    OPTIONS              VARCHAR2(4000) DEFAULT NULL,
	CONSTRAINT XAK1SBI_PARUSE UNIQUE (PAR_ID,LABEL),
    PRIMARY KEY (USE_ID),
    CONSTRAINT FK_SBI_PARUSE_4 FOREIGN KEY (MAX_LOV_ID) REFERENCES SBI_LOV (LOV_ID)
);


CREATE TABLE SBI_PARUSE_CK (
	USE_ID INTEGER NOT NULL ,
	CHECK_ID INTEGER NOT NULL ,
	PROG INTEGER,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
PRIMARY KEY (USE_ID,CHECK_ID)
);


CREATE TABLE SBI_PARUSE_DET (
	USE_ID INTEGER NOT NULL ,
	EXT_ROLE_ID INTEGER NOT NULL ,
	PROG INTEGER,
	HIDDEN_FL SMALLINT,
	DEFAULT_VAL VARCHAR2 (40),
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
PRIMARY KEY (USE_ID,EXT_ROLE_ID)
);


CREATE TABLE SBI_SUBREPORTS (
	MASTER_RPT_ID INTEGER NOT NULL ,
	SUB_RPT_ID INTEGER NOT NULL ,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
PRIMARY KEY (MASTER_RPT_ID,SUB_RPT_ID)
);


CREATE TABLE SBI_OBJ_PARUSE (
	OBJ_PAR_ID INTEGER NOT NULL ,
	PARUSE_ID INTEGER NOT NULL ,
	USE_ID INTEGER NOT NULL ,
	OBJ_PAR_FATHER_ID INTEGER NOT NULL ,
	FILTER_OPERATION VARCHAR2 (20) NOT NULL ,
	PROG INTEGER NOT NULL ,
	FILTER_COLUMN VARCHAR2 (30) NOT NULL ,
	PRE_CONDITION VARCHAR2 (10),
	POST_CONDITION VARCHAR2 (10),
	LOGIC_OPERATOR VARCHAR2 (10),
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
    CONSTRAINT XAK1SBI_OBJ_PARUSE UNIQUE (OBJ_PAR_ID,USE_ID,OBJ_PAR_FATHER_ID,FILTER_OPERATION),
PRIMARY KEY (PARUSE_ID)
);


CREATE TABLE SBI_EVENTS (
	ID INTEGER NOT NULL ,
	USER_EVENT VARCHAR2 (40) NOT NULL ,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
PRIMARY KEY (ID)
);

CREATE TABLE SBI_EVENTS_LOG (
	ID INTEGER NOT NULL ,
	USER_EVENT VARCHAR2 (40) NOT NULL ,
	EVENT_DATE DATE NOT NULL ,
	DESCR VARCHAR2 (4000) NOT NULL ,
	PARAMS VARCHAR2 (1000),
	EVENT_TYPE 			 VARCHAR2(50) NOT NULL,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_EVENTS_ROLES (
	EVENT_ID INTEGER NOT NULL ,
	ROLE_ID INTEGER NOT NULL ,
PRIMARY KEY (EVENT_ID,ROLE_ID)
);

CREATE TABLE SBI_AUDIT (
	ID INTEGER NOT NULL ,
	USERNAME VARCHAR2 (40) NOT NULL ,
	USERGROUP VARCHAR2 (100),
	DOC_REF INTEGER,
	DOC_ID INTEGER,
	DOC_LABEL VARCHAR2 (200) NOT NULL ,
	DOC_NAME VARCHAR2 (200) NOT NULL ,
	DOC_TYPE VARCHAR2 (20) NOT NULL ,
	DOC_STATE VARCHAR2 (20) NOT NULL ,
	DOC_PARAMETERS CLOB,
	SUBOBJ_REF INTEGER,
	SUBOBJ_ID INTEGER,
	SUBOBJ_NAME VARCHAR2 (50),
	SUBOBJ_OWNER VARCHAR2 (50),
	SUBOBJ_ISPUBLIC SMALLINT,
	ENGINE_REF INTEGER,
	ENGINE_ID INTEGER,
	ENGINE_LABEL VARCHAR2 (40) NOT NULL ,
	ENGINE_NAME VARCHAR2 (40) NOT NULL ,
	ENGINE_TYPE VARCHAR2 (20) NOT NULL ,
	ENGINE_URL VARCHAR2 (400),
	ENGINE_DRIVER VARCHAR2 (400),
	ENGINE_CLASS VARCHAR2 (400),
	REQUEST_TIME TIMESTAMP(6) NOT NULL ,
	EXECUTION_START DATE,
	EXECUTION_END DATE,
	EXECUTION_TIME INTEGER,
	EXECUTION_STATE VARCHAR2 (20),
	ERROR SMALLINT,
	ERROR_MESSAGE VARCHAR2 (400),
	ERROR_CODE VARCHAR2 (20),
	EXECUTION_MODALITY VARCHAR2 (40),
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
PRIMARY KEY (ID)
);


CREATE TABLE SBI_ACTIVITY_MONITORING (
  ID INTEGER NOT NULL,
  ACTION_TIME TIMESTAMP,
  USERNAME 	 	VARCHAR2(40) NOT NULL,
  USERGROUP		VARCHAR2(400),
  LOG_LEVEL 	VARCHAR2(10) ,
  ACTION_CODE 	VARCHAR2(45) NOT NULL,
  INFO 			VARCHAR2(400),
  PRIMARY KEY (ID)
);


CREATE TABLE SBI_GEO_MAPS (
	MAP_ID INTEGER NOT NULL ,
	NAME VARCHAR2 (40) NOT NULL ,
	DESCR VARCHAR2 (160),
	URL VARCHAR2 (400) ,
	FORMAT VARCHAR2 (40),
	HIERARCHY_NAME VARCHAR2(100),
	NUM_LEVEL INTEGER,
	MEMBER_NAME VARCHAR2(100),
	BIN_ID INTEGER,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
    CONSTRAINT XAK1SBI_GEO_MAPS UNIQUE (NAME, ORGANIZATION),
PRIMARY KEY (MAP_ID)
);


CREATE TABLE SBI_GEO_FEATURES (
	FEATURE_ID INTEGER NOT NULL ,
	NAME VARCHAR2 (40) NOT NULL ,
	DESCR VARCHAR2 (160),
	TYPE VARCHAR2 (40),
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
    CONSTRAINT XAK1SBI_GEO_FEATURES UNIQUE (NAME, ORGANIZATION),
PRIMARY KEY (FEATURE_ID)
);


CREATE TABLE SBI_GEO_MAP_FEATURES (
	MAP_ID INTEGER NOT NULL ,
	FEATURE_ID INTEGER NOT NULL ,
	SVG_GROUP VARCHAR2 (40),
	VISIBLE_FLAG VARCHAR2 (1),
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
PRIMARY KEY (MAP_ID,FEATURE_ID)
);


CREATE TABLE SBI_VIEWPOINTS (
	VP_ID INTEGER NOT NULL ,
	BIOBJ_ID INTEGER NOT NULL ,
	VP_NAME VARCHAR2 (40) NOT NULL ,
	VP_OWNER VARCHAR2 (40),
	VP_DESC VARCHAR2 (160),
	VP_SCOPE VARCHAR2 (20) NOT NULL ,
	VP_VALUE_PARAMS CLOB,
	VP_CREATION_DATE TIMESTAMP(6) NOT NULL ,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
PRIMARY KEY (VP_ID)
);


CREATE TABLE SBI_DATA_SOURCE (
	DS_ID INTEGER NOT NULL ,
	DESCR VARCHAR2 (160),
	LABEL VARCHAR2 (50) NOT NULL ,
	JNDI VARCHAR2 (50),
	URL_CONNECTION VARCHAR2 (500),
	USERNAME VARCHAR2 (50),
	PWD VARCHAR2 (50),
	DRIVER VARCHAR2 (160),
	DIALECT_ID INTEGER NOT NULL ,
    MULTI_SCHEMA NUMBER(38,0) DEFAULT 0,
	ATTR_SCHEMA VARCHAR2(45) DEFAULT NULL ,
	READ_ONLY            SMALLINT DEFAULT 0,
	WRITE_DEFAULT        SMALLINT DEFAULT 0,
	JDBC_ADVANCED_CONFIGURATION	VARCHAR2(4000),
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
	USE_FOR_DATAPREP 	 SMALLINT DEFAULT 0, 
    CONSTRAINT XAK1SBI_DATA_SOURCE UNIQUE (LABEL),
PRIMARY KEY (DS_ID)
);


CREATE TABLE SBI_BINARY_CONTENTS (
	BIN_ID INTEGER NOT NULL ,
	BIN_CONTENT BLOB NOT NULL ,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
PRIMARY KEY (BIN_ID)
);


CREATE TABLE SBI_OBJECT_TEMPLATES (
	OBJ_TEMP_ID INTEGER NOT NULL ,
	BIOBJ_ID INTEGER NOT NULL ,
	BIN_ID INTEGER,
	NAME VARCHAR2 (1000),
	PROG INTEGER,
	DIMENSION VARCHAR2 (20),
	CREATION_DATE DATE,
	CREATION_USER VARCHAR2 (45) NOT NULL ,
	ACTIVE SMALLINT,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
PRIMARY KEY (OBJ_TEMP_ID)
);


CREATE TABLE SBI_OBJECT_NOTES (
	OBJ_NOTE_ID INTEGER NOT NULL ,
	BIOBJ_ID INTEGER NOT NULL ,
	BIN_ID INTEGER,
	EXEC_REQ VARCHAR2 (500),
	OWNER VARCHAR2 (50),
	ISPUBLIC SMALLINT,
	CREATION_DATE TIMESTAMP(6) NOT NULL ,
	LAST_CHANGE_DATE TIMESTAMP(6) NOT NULL ,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
PRIMARY KEY (OBJ_NOTE_ID)
);


CREATE TABLE SBI_SUBOBJECTS (
	SUBOBJ_ID INTEGER NOT NULL ,
	BIOBJ_ID INTEGER NOT NULL ,
	BIN_ID INTEGER,
	NAME VARCHAR2 (50) NOT NULL,
	DESCRIPTION VARCHAR2 (100),
	OWNER VARCHAR2 (50),
	ISPUBLIC SMALLINT,
	CREATION_DATE TIMESTAMP(6) NOT NULL ,
	LAST_CHANGE_DATE TIMESTAMP(6) NOT NULL ,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
PRIMARY KEY (SUBOBJ_ID)
);


CREATE TABLE SBI_SNAPSHOTS (
	SNAP_ID INTEGER NOT NULL ,
	BIOBJ_ID INTEGER NOT NULL ,
	BIN_ID INTEGER,
	NAME VARCHAR2 (100),
	DESCRIPTION VARCHAR2 (1000),
	CREATION_DATE TIMESTAMP(6) NOT NULL ,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
    CONTENT_TYPE 		 VARCHAR2(300) DEFAULT NULL,
	SCHEDULATION		 VARCHAR2(100),
	SCHEDULER			 VARCHAR2(100),
	SCHEDULATION_START	 INTEGER,
	SEQUENCE INTEGER,
PRIMARY KEY (SNAP_ID)
);


CREATE TABLE SBI_USER_FUNC (
	USER_FUNCT_ID INTEGER NOT NULL ,
	NAME VARCHAR2 (50),
	DESCRIPTION VARCHAR2 (100),
	PRODUCT_TYPE_ID INTEGER NOT NULL,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
PRIMARY KEY (USER_FUNCT_ID)
);


CREATE TABLE SBI_ROLE_TYPE_USER_FUNC (
	ROLE_TYPE_ID INTEGER NOT NULL ,
	USER_FUNCT_ID INTEGER NOT NULL ,
PRIMARY KEY (ROLE_TYPE_ID,USER_FUNCT_ID)
);


CREATE TABLE SBI_DIST_LIST (
	DL_ID INTEGER NOT NULL ,
	NAME VARCHAR2 (40) NOT NULL ,
	DESCR VARCHAR2 (160),
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
    CONSTRAINT XAK1SBI_SBI_DIST_LIST UNIQUE (NAME, ORGANIZATION),
PRIMARY KEY (DL_ID)
);


CREATE TABLE SBI_DIST_LIST_USER (
	DLU_ID INTEGER NOT NULL ,
	LIST_ID INTEGER NOT NULL ,
	USER_ID VARCHAR2 (40) NOT NULL ,
	E_MAIL VARCHAR2 (70) NOT NULL ,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
	CONSTRAINT XAK1SBI_DL_USER UNIQUE (LIST_ID, USER_ID),
PRIMARY KEY (DLU_ID)
);


CREATE TABLE SBI_DIST_LIST_OBJECTS (
	REL_ID INTEGER NOT NULL ,
	DOC_ID INTEGER NOT NULL ,
	DL_ID INTEGER NOT NULL ,
	XML VARCHAR2 (4000) NOT NULL ,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
PRIMARY KEY (REL_ID)
);


CREATE TABLE SBI_REMEMBER_ME (
	ID INTEGER NOT NULL ,
	USERNAME VARCHAR2 (40) NOT NULL ,
	BIOBJ_ID INTEGER NOT NULL ,
	SUBOBJ_ID INTEGER,
	PARAMETERS CLOB,
	NAME VARCHAR2 (50) NOT NULL ,
	DESCRIPTION CLOB,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
PRIMARY KEY (ID)
);

CREATE TABLE SBI_DATA_SET (
	   DS_ID 		   		  INTEGER NOT NULL ,
	   VERSION_NUM	   		  INTEGER NOT NULL,
	   ACTIVE		   		  SMALLINT NOT NULL,
	   DESCR 		   		  VARCHAR2(160),
	   LABEL	 	   		  VARCHAR2(50) NOT NULL,
	   NAME	   	   			  VARCHAR2(50) NOT NULL,
	   OBJECT_TYPE   		  VARCHAR2(50),
	   DS_METADATA    		  CLOB,
	   PARAMS         		  VARCHAR2(4000),
	   CATEGORY_ID    		  INTEGER,
	   TRANSFORMER_ID 		  INTEGER,
	   PIVOT_COLUMN   		  VARCHAR2(50),
	   PIVOT_ROW      		  VARCHAR2(50),
	   PIVOT_VALUE   		  VARCHAR2(50),
	   NUM_ROWS	   		 	  SMALLINT DEFAULT 0,
	   IS_PERSISTED  		  SMALLINT DEFAULT 0,
	   IS_PERSISTED_HDFS	  SMALLINT DEFAULT 0,
	   PERSIST_TABLE_NAME     VARCHAR2(50),
	   CONFIGURATION          CLOB NULL,
	   OWNER 				  VARCHAR2(50),
	   USER_IN                VARCHAR2(100) NOT NULL,
	   USER_UP                VARCHAR2(100),
	   USER_DE                VARCHAR2(100),
	   TIME_IN                TIMESTAMP NOT NULL,
	   TIME_UP                TIMESTAMP NULL,
	   TIME_DE                TIMESTAMP NULL,
	   SBI_VERSION_IN         VARCHAR2(10),
	   SBI_VERSION_UP         VARCHAR2(10),
	   SBI_VERSION_DE         VARCHAR2(10),
	   META_VERSION           VARCHAR2(100),
	   ORGANIZATION           VARCHAR2(20),
	   SCOPE_ID 			  INTEGER NULL,
	   FEDERATION_ID          INTEGER DEFAULT NULL,
     CONSTRAINT XAK1SBI_DATA_SET UNIQUE (LABEL,VERSION_NUM, ORGANIZATION),
	 CONSTRAINT XAK2SBI_DATA_SET UNIQUE (NAME, VERSION_NUM, ORGANIZATION),
     PRIMARY KEY (DS_ID, VERSION_NUM,ORGANIZATION)
);


CREATE TABLE SBI_MENU (
		MENU_ID INTEGER NOT NULL,
		NAME VARCHAR2(50),
		DESCR VARCHAR2(2000),
		PARENT_ID INTEGER DEFAULT 0,
		BIOBJ_ID INTEGER,
		VIEW_ICONS SMALLINT DEFAULT 0,
		HIDE_TOOLBAR SMALLINT DEFAULT 0,
		HIDE_SLIDERS SMALLINT DEFAULT 0,
		STATIC_PAGE VARCHAR2(45),
		BIOBJ_PARAMETERS CLOB NULL,
		SUBOBJ_NAME VARCHAR2(50) NULL,
		SNAPSHOT_NAME VARCHAR2(100) NULL,
		SNAPSHOT_HISTORY INTEGER NULL,
		FUNCTIONALITY VARCHAR2(50) NULL,
		INITIAL_PATH VARCHAR2(400) NULL,
		ICON 				 VARCHAR2(1000) NULL,
		CUST_ICON 			 CLOB NULL,	
		EXT_APP_URL VARCHAR2(1000) NULL,
		PROG INTEGER  DEFAULT 1 NOT NULL,
		USER_IN              VARCHAR2(100) NOT NULL,
		USER_UP              VARCHAR2(100),
		USER_DE              VARCHAR2(100),
		TIME_IN              TIMESTAMP NOT NULL,
		TIME_UP              TIMESTAMP DEFAULT NULL,
		TIME_DE              TIMESTAMP DEFAULT NULL,
		SBI_VERSION_IN       VARCHAR2(10),
		SBI_VERSION_UP       VARCHAR2(10),
		SBI_VERSION_DE       VARCHAR2(10),
		META_VERSION         VARCHAR2(100),
		ORGANIZATION         VARCHAR2(20),
PRIMARY KEY (MENU_ID)
);

CREATE TABLE SBI_MENU_ROLE (
       MENU_ID INTEGER NOT NULL,
       EXT_ROLE_ID INTEGER NOT NULL,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
PRIMARY KEY (MENU_ID, EXT_ROLE_ID)
);


CREATE TABLE SBI_EXPORTERS (
	ENGINE_ID INTEGER NOT NULL,
	DOMAIN_ID INTEGER NOT NULL,
	DEFAULT_VALUE NUMBER(38,0) DEFAULT 0,
	CONSTRAINT XAK1SBI_EXPORTERS UNIQUE (ENGINE_ID, DOMAIN_ID),
PRIMARY KEY (DOMAIN_ID,ENGINE_ID)
);

CREATE TABLE SBI_OBJ_METADATA (
	OBJ_META_ID 		INTEGER NOT NULL,
    LABEL	 	        VARCHAR2(20) NOT NULL,
    NAME 	            VARCHAR2(40) NOT NULL,
    DESCR		        VARCHAR2(100),
    DATA_TYPE_ID		INTEGER NOT NULL,
    CREATION_DATE 	    TIMESTAMP(6) NOT NULL,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
    CONSTRAINT XAK1SBI_OBJ_METADATA UNIQUE (LABEL, ORGANIZATION),
    PRIMARY KEY (OBJ_META_ID)
);

CREATE TABLE SBI_OBJ_METACONTENTS (
  OBJ_METACONTENT_ID INTEGER  NOT NULL ,
  OBJMETA_ID 		 INTEGER  NOT NULL ,
  BIOBJ_ID 			 INTEGER  NOT NULL,
  SUBOBJ_ID 		 INTEGER,
  BIN_ID 			 INTEGER,
  CREATION_DATE 	 TIMESTAMP(6) NOT NULL,
  LAST_CHANGE_DATE   TIMESTAMP(6) NOT NULL,
  ADDITIONAL_INFO	 VARCHAR2(255),
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
    PRIMARY KEY (OBJ_METACONTENT_ID)
);

CREATE TABLE SBI_CONFIG (
	ID 				INTEGER NOT NULL,
	LABEL			VARCHAR2(100) NOT NULL,
	NAME			VARCHAR2(100) NULL,
	DESCRIPTION 	VARCHAR2(500) NULL,
	IS_ACTIVE 		SMALLINT DEFAULT 1,
	VALUE_CHECK 	VARCHAR2(1000) NULL,
	VALUE_TYPE_ID 	INTEGER NULL,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
    CATEGORY             VARCHAR2(50),
	PRIMARY KEY (ID)
);

CREATE TABLE SBI_USER (
	USER_ID VARCHAR2(100) NOT NULL,
	PASSWORD VARCHAR2(150),
	FULL_NAME VARCHAR2(255),
	ID INTEGER NOT NULL,
	DT_PWD_BEGIN TIMESTAMP(6),
	DT_PWD_END TIMESTAMP(6),
	FLG_PWD_BLOCKED SMALLINT,
	DT_LAST_ACCESS TIMESTAMP(6),
	FAILED_LOGIN_ATTEMPTS INTEGER DEFAULT 0 NOT NULL,
	DEFAULT_ROLE_ID INTEGER DEFAULT NULL,
	IS_SUPERADMIN 		SMALLINT DEFAULT 0,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
	CONSTRAINT FK_SBI_USER_1 FOREIGN KEY (DEFAULT_ROLE_ID) REFERENCES SBI_EXT_ROLES(EXT_ROLE_ID),
 PRIMARY KEY (ID)
);

CREATE TABLE SBI_ATTRIBUTE (
	ATTRIBUTE_NAME VARCHAR2(255) NOT NULL,
	DESCRIPTION VARCHAR2(500) NULL,
	ATTRIBUTE_ID INTEGER NOT NULL,
	LOV_ID 				 INTEGER NULL,
	ALLOW_USER 			 SMALLINT DEFAULT '1',
	MULTIVALUE 			 SMALLINT DEFAULT '0',
	SYNTAX 				 SMALLINT ,
	VALUE_TYPE_ID		 INTEGER NULL,
	VALUE_TYPE_CD		 VARCHAR2(20),
	VALUE_TYPE 			 VARCHAR2(50),
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
    CONSTRAINT ENUM_TYPE CHECK (VALUE_TYPE IN('STRING','DATE','NUM')),
    CONSTRAINT XAK1SBI_ATTRIBUTE UNIQUE ( ATTRIBUTE_NAME, ORGANIZATION ),
	PRIMARY KEY (ATTRIBUTE_ID)
);

CREATE TABLE SBI_USER_ATTRIBUTES (
	ID INTEGER NOT NULL,
	ATTRIBUTE_ID INTEGER NOT NULL,
	ATTRIBUTE_VALUE VARCHAR2(500),
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
 PRIMARY KEY (ID,ATTRIBUTE_ID)
);

CREATE TABLE SBI_EXT_USER_ROLES (
	ID INTEGER NOT NULL,
	EXT_ROLE_ID INTEGER NOT NULL,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
 PRIMARY KEY (ID,EXT_ROLE_ID)
);

CREATE TABLE SBI_UDP (
	UDP_ID	        INTEGER  NOT NULL,
	TYPE_ID			INTEGER NOT NULL,
	FAMILY_ID		INTEGER NOT NULL,
	LABEL           VARCHAR2(20) NOT NULL,
	NAME            VARCHAR2(40) NOT NULL,
	DESCRIPTION     VARCHAR2(1000) NULL,
	IS_MULTIVALUE   SMALLINT DEFAULT 0,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
    CONSTRAINT XAK1SBI_UDP UNIQUE (LABEL, ORGANIZATION),
 PRIMARY KEY (UDP_ID)
);

 CREATE TABLE SBI_UDP_VALUE (
	UDP_VALUE_ID       INTEGER  NOT NULL,
	UDP_ID			   INTEGER NOT NULL,
	VALUE              VARCHAR2(1000) NULL,
	PROG               INTEGER NULL,
	LABEL              VARCHAR2(20) NULL,
	NAME               VARCHAR2(40) NULL,
	FAMILY			   VARCHAR2(40) NULL,
    BEGIN_TS           TIMESTAMP NOT NULL,
    END_TS             TIMESTAMP NULL,
    REFERENCE_ID	   INTEGER NULL,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
 PRIMARY KEY (UDP_VALUE_ID)
);


CREATE TABLE SBI_OBJ_PARVIEW (
       OBJ_PAR_ID 			INTEGER NOT NULL,
	   PARVIEW_ID			INTEGER NOT NULL,
   	   OBJ_PAR_FATHER_ID    INTEGER NOT NULL,
       OPERATION  			VARCHAR2(20) NOT NULL,
   	   COMPARE_VALUE  		VARCHAR2(200) NOT NULL,
   	   VIEW_LABEL   		VARCHAR2(50),
	     PROG INTEGER,
       USER_IN           	VARCHAR2(100) NOT NULL,
       USER_UP              VARCHAR2(100),
       USER_DE              VARCHAR2(100),
       TIME_IN              TIMESTAMP NOT NULL,
       TIME_UP              TIMESTAMP DEFAULT NULL,
       TIME_DE              TIMESTAMP DEFAULT NULL,
       SBI_VERSION_IN       VARCHAR2(10),
       SBI_VERSION_UP       VARCHAR2(10),
       SBI_VERSION_DE       VARCHAR2(10),
       META_VERSION         VARCHAR2(100),
       ORGANIZATION         VARCHAR2(20),
  PRIMARY KEY ( PARVIEW_ID )
);

CREATE TABLE SBI_I18N_MESSAGES (
  ID INTEGER NOT NULL,
  LANGUAGE_CD INTEGER NOT NULL,
  LABEL VARCHAR(200) NOT NULL,
  MESSAGE CLOB,
  USER_IN              VARCHAR2(100) NOT NULL,
  USER_UP              VARCHAR2(100),
  USER_DE              VARCHAR2(100),
  TIME_IN              TIMESTAMP NOT NULL,
  TIME_UP              TIMESTAMP DEFAULT NULL,
  TIME_DE              TIMESTAMP DEFAULT NULL,
  SBI_VERSION_IN       VARCHAR2(10),
  SBI_VERSION_UP       VARCHAR2(10),
  SBI_VERSION_DE       VARCHAR2(10),
  META_VERSION         VARCHAR2(100),
  ORGANIZATION         VARCHAR2(20),
  PRIMARY KEY (ID)
);


CREATE TABLE SBI_PROGRESS_THREAD (
       PROGRESS_THREAD_ID   INTEGER NOT NULL,
       USER_ID              VARCHAR2(100) NOT NULL,
       PARTIAL              INTEGER,
       TOTAL        	      INTEGER,
       FUNCTION_CD         VARCHAR2(200),
       STATUS              VARCHAR2(4000),
       RANDOM_KEY			VARCHAR2(4000),
       TYPE 				VARCHAR2(200),
       PRIMARY KEY (PROGRESS_THREAD_ID)
);


CREATE TABLE SBI_ORGANIZATIONS (
       ID     INTEGER NOT NULL,
       NAME   VARCHAR2(20),
       THEME  VARCHAR2(100) DEFAULT 'SPAGOBI.THEMES.THEME.default',
       CONSTRAINT XAK1SBI_ORGANIZATIONS UNIQUE (NAME),
       PRIMARY KEY (ID)
);

CREATE TABLE SBI_META_MODELS (
       ID                   INTEGER NOT NULL,
       NAME                 VARCHAR2(100) NOT NULL,
       DESCR                VARCHAR2(500) NULL,
       MODEL_LOCKED         SMALLINT NULL,
       MODEL_LOCKER         VARCHAR2(100) NULL,
       SMART_VIEW 			SMALLINT DEFAULT 1,
       USER_IN              VARCHAR2(100) NOT NULL,
       USER_UP              VARCHAR2(100),
       USER_DE              VARCHAR2(100),
       TIME_IN              TIMESTAMP NOT NULL,
       TIME_UP              TIMESTAMP DEFAULT NULL,
       TIME_DE              TIMESTAMP DEFAULT NULL,
       SBI_VERSION_IN       VARCHAR2(10),
       SBI_VERSION_UP       VARCHAR2(10),
       SBI_VERSION_DE       VARCHAR2(10),
       META_VERSION         VARCHAR2(100),
       ORGANIZATION         VARCHAR2(20),
       CATEGORY_ID			INTEGER NULL,
       DATA_SOURCE_ID		INTEGER,
	TABLE_PREFIX_LIKE VARCHAR2(4000 BYTE), 
	TABLE_PREFIX_NOT_LIKE VARCHAR2(4000 BYTE), 
       CONSTRAINT XAK1SBI_META_MODELS UNIQUE (NAME, ORGANIZATION),
       PRIMARY KEY (ID)
);

CREATE TABLE SBI_META_MODELS_VERSIONS (
        ID                   INTEGER NOT NULL,
        MODEL_ID             INTEGER NOT NULL,
        CONTENT              BLOB,
        NAME                 VARCHAR2(100),
        FILE_MODEL           BLOB,
        PROG                 INTEGER,
        CREATION_DATE        TIMESTAMP DEFAULT NULL,
        CREATION_USER        VARCHAR2(50) NOT NULL ,
        ACTIVE               SMALLINT,
        USER_IN              VARCHAR2(100) NOT NULL,
        USER_UP              VARCHAR2(100),
        USER_DE              VARCHAR2(100),
        TIME_IN              TIMESTAMP NOT NULL,
        TIME_UP              TIMESTAMP DEFAULT NULL,
        TIME_DE              TIMESTAMP DEFAULT NULL,
        SBI_VERSION_IN       VARCHAR2(10),
        SBI_VERSION_UP       VARCHAR2(10),
        SBI_VERSION_DE       VARCHAR2(10),
        META_VERSION         VARCHAR2(100),
        ORGANIZATION         VARCHAR2(20),
        PRIMARY KEY (ID)
);



CREATE TABLE SBI_ARTIFACTS (
       ID                   INTEGER NOT NULL,
       NAME                 VARCHAR2(100) NOT NULL,
       DESCR                VARCHAR2(500) NULL,
       TYPE                 VARCHAR2(50) NULL,
       MODEL_LOCKED         SMALLINT NULL,
       MODEL_LOCKER         VARCHAR2(100) NULL,
       USER_IN              VARCHAR2(100) NOT NULL,
       USER_UP              VARCHAR2(100),
       USER_DE              VARCHAR2(100),
       TIME_IN              TIMESTAMP NOT NULL,
       TIME_UP              TIMESTAMP DEFAULT NULL,
       TIME_DE              TIMESTAMP DEFAULT NULL,
       SBI_VERSION_IN       VARCHAR2(10),
       SBI_VERSION_UP       VARCHAR2(10),
       SBI_VERSION_DE       VARCHAR2(10),
       META_VERSION         VARCHAR2(100),
       ORGANIZATION         VARCHAR2(20),
       CONSTRAINT XAK1SBI_ARTIFACTS UNIQUE (NAME, TYPE, ORGANIZATION),
       PRIMARY KEY (ID)
);

CREATE TABLE SBI_ARTIFACTS_VERSIONS (
        ID                   INTEGER NOT NULL,
        ARTIFACT_ID          INTEGER NOT NULL,
        CONTENT              BLOB NOT NULL,
        NAME                 VARCHAR2(100),
        PROG                 INTEGER,
        CREATION_DATE        TIMESTAMP DEFAULT NULL,
        CREATION_USER        VARCHAR2(50) NOT NULL ,
        ACTIVE               SMALLINT,
        USER_IN              VARCHAR2(100) NOT NULL,
        USER_UP              VARCHAR2(100),
        USER_DE              VARCHAR2(100),
        TIME_IN              TIMESTAMP NOT NULL,
        TIME_UP              TIMESTAMP DEFAULT NULL,
        TIME_DE              TIMESTAMP DEFAULT NULL,
        SBI_VERSION_IN       VARCHAR2(10),
        SBI_VERSION_UP       VARCHAR2(10),
        SBI_VERSION_DE       VARCHAR2(10),
        META_VERSION         VARCHAR2(100),
        ORGANIZATION         VARCHAR2(20),
        PRIMARY KEY (ID)
);

CREATE TABLE  SBI_EXT_ROLES_CATEGORY (
  EXT_ROLE_ID INTEGER NOT NULL,
  CATEGORY_ID INTEGER NOT NULL,
  PRIMARY KEY (EXT_ROLE_ID,CATEGORY_ID),
  CONSTRAINT FK_SB_EXT_ROLES_META_MODEL_C_1 FOREIGN KEY (EXT_ROLE_ID) REFERENCES SBI_EXT_ROLES (EXT_ROLE_ID),
  CONSTRAINT FK_SB_EXT_ROLES_META_MODEL_C_2 FOREIGN KEY (CATEGORY_ID) REFERENCES SBI_DOMAINS (VALUE_ID)
);


CREATE TABLE  SBI_COMMUNITY(
  COMMUNITY_ID INTEGER NOT NULL,
  NAME VARCHAR2(200) NOT NULL,
  DESCRIPTION  VARCHAR2(350),
  OWNER VARCHAR2(100) NOT NULL,
  FUNCT_CODE VARCHAR2(40) DEFAULT NULL,
  CREATION_DATE TIMESTAMP NOT NULL,
  LAST_CHANGE_DATE TIMESTAMP NOT NULL,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
	TIME_IN              TIMESTAMP NOT NULL,
	TIME_UP              TIMESTAMP DEFAULT NULL,
	TIME_DE              TIMESTAMP DEFAULT NULL,
	SBI_VERSION_IN       VARCHAR2(10),
	SBI_VERSION_UP       VARCHAR2(10),
	SBI_VERSION_DE       VARCHAR2(10),
	META_VERSION         VARCHAR2(100),
	ORGANIZATION         VARCHAR2(20),
  PRIMARY KEY (COMMUNITY_ID)
);

CREATE TABLE SBI_COMMUNITY_USERS (
  COMMUNITY_ID INTEGER NOT NULL,
  USER_ID VARCHAR2(100) NOT NULL,
  CREATION_DATE TIMESTAMP NOT NULL,
  LAST_CHANGE_DATE TIMESTAMP NOT NULL,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
	TIME_IN              TIMESTAMP NOT NULL,
	TIME_UP              TIMESTAMP DEFAULT NULL,
	TIME_DE              TIMESTAMP DEFAULT NULL,
	SBI_VERSION_IN       VARCHAR2(10),
	SBI_VERSION_UP       VARCHAR2(10),
	SBI_VERSION_DE       VARCHAR2(10),
	META_VERSION         VARCHAR2(100),
	ORGANIZATION         VARCHAR2(20),
  PRIMARY KEY (COMMUNITY_ID,USER_ID)
);


CREATE TABLE SBI_GEO_LAYERS (
  	LAYER_ID 			 INTEGER NOT NULL,
  	LABEL 				 VARCHAR2(100) NOT NULL,
  	NAME 				 VARCHAR2(100),
  	DESCR 				 VARCHAR2(100),
  	LAYER_DEFINITION 	 BLOB NOT NULL,
  	TYPE 				 VARCHAR2(40),
  	IS_BASE_LAYER SMALLINT DEFAULT 0 NOT NULL,
  	GEO_CATEGORY 		 INTEGER,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
	TIME_IN              TIMESTAMP NOT NULL,
	TIME_UP              TIMESTAMP DEFAULT NULL,
	TIME_DE              TIMESTAMP DEFAULT NULL,
	SBI_VERSION_IN       VARCHAR2(10),
	SBI_VERSION_UP       VARCHAR2(10),
	SBI_VERSION_DE       VARCHAR2(10),
	META_VERSION         VARCHAR2(100),
	ORGANIZATION         VARCHAR2(20),
  	CONSTRAINT LABEL_UNIQUE UNIQUE (LABEL,ORGANIZATION),
  	PRIMARY KEY (LAYER_ID)
);


CREATE TABLE SBI_AUTHORIZATIONS (
  ID INTEGER NOT NULL,
  NAME VARCHAR2(200) DEFAULT NULL,
  PRODUCT_TYPE_ID INTEGER NOT NULL,
  USER_IN VARCHAR2(100) NOT NULL,
  USER_UP VARCHAR2(100) DEFAULT NULL,
  USER_DE VARCHAR2(100) DEFAULT NULL,
  TIME_IN timestamp NOT NULL,
  TIME_UP timestamp DEFAULT NULL,
  TIME_DE timestamp DEFAULT NULL,
  SBI_VERSION_IN VARCHAR2(10) DEFAULT NULL,
  SBI_VERSION_UP VARCHAR2(10) DEFAULT NULL,
  SBI_VERSION_DE VARCHAR2(10) DEFAULT NULL,
  META_VERSION VARCHAR2(100) DEFAULT NULL,
  ORGANIZATION VARCHAR2(20) DEFAULT NULL,
  PRIMARY KEY (ID)
);

CREATE TABLE SBI_AUTHORIZATIONS_ROLES (
  AUTHORIZATION_ID INTEGER NOT NULL,
  ROLE_ID INTEGER NOT NULL,
  USER_IN VARCHAR2(100) NOT NULL,
  USER_UP VARCHAR2(100) DEFAULT NULL,
  USER_DE VARCHAR2(100) DEFAULT NULL,
  TIME_IN timestamp NOT NULL,
  TIME_UP timestamp  DEFAULT NULL,
  TIME_DE timestamp  DEFAULT NULL,
  SBI_VERSION_IN VARCHAR2(10) DEFAULT NULL,
  SBI_VERSION_UP VARCHAR2(10) DEFAULT NULL,
  SBI_VERSION_DE VARCHAR2(10) DEFAULT NULL,
  META_VERSION VARCHAR2(100) DEFAULT NULL,
  ORGANIZATION VARCHAR2(20) DEFAULT NULL,
  PRIMARY KEY (AUTHORIZATION_ID,ROLE_ID )
);


CREATE TABLE SBI_ORGANIZATION_DATASOURCE (
  DATASOURCE_ID NUMBER(11) NOT NULL,
  ORGANIZATION_ID NUMBER(11) NOT NULL,
  USER_IN VARCHAR2(100) NOT NULL,
  USER_UP VARCHAR2(100) DEFAULT NULL,
  USER_DE VARCHAR2(100) DEFAULT NULL,
  TIME_IN TIMESTAMP DEFAULT NULL,
  TIME_UP TIMESTAMP DEFAULT NULL,
  TIME_DE TIMESTAMP DEFAULT NULL,
  SBI_VERSION_IN VARCHAR2(10) DEFAULT NULL,
  SBI_VERSION_UP VARCHAR2(10) DEFAULT NULL,
  SBI_VERSION_DE VARCHAR2(10) DEFAULT NULL,
  META_VERSION VARCHAR2(100) DEFAULT NULL,
  ORGANIZATION VARCHAR2(20) DEFAULT NULL,
  PRIMARY KEY (DATASOURCE_ID,ORGANIZATION_ID )
);

CREATE TABLE SBI_TRIGGER_PAUSED (
	   ID 					INTEGER  NOT NULL ,
       TRIGGER_NAME	 	    VARCHAR2(80) NOT NULL,
       TRIGGER_GROUP 	    VARCHAR2(80) NOT NULL,
       JOB_NAME 	        VARCHAR2(80) NOT NULL,
       JOB_GROUP 	        VARCHAR2(80) NOT NULL,
       USER_IN              VARCHAR2(100) NOT NULL,
       USER_UP              VARCHAR2(100),
       USER_DE              VARCHAR2(100),
       TIME_IN              TIMESTAMP NOT NULL,
       TIME_UP              TIMESTAMP DEFAULT NULL,
       TIME_DE              TIMESTAMP DEFAULT NULL,
       SBI_VERSION_IN       VARCHAR2(10),
       SBI_VERSION_UP       VARCHAR2(10),
       SBI_VERSION_DE       VARCHAR2(10),
       META_VERSION         VARCHAR2(100),
       ORGANIZATION         VARCHAR2(20),
       CONSTRAINT XAK1SBI_TRIGGER_PAUSED UNIQUE(TRIGGER_NAME, TRIGGER_GROUP, JOB_NAME, JOB_GROUP),
       PRIMARY KEY (ID)
);

CREATE TABLE SBI_CACHE_ITEM (
	   SIGNATURE			VARCHAR2(100) NOT NULL,
	   NAME					CLOB NOT NULL,
	   TABLE_NAME 			VARCHAR2(100) NOT NULL,
	   DIMENSION 			NUMERIC NULL,
	   CREATION_DATE 		DATE NULL,
	   LAST_USED_DATE 		DATE NULL,
       PROPERTIES			CLOB NULL,
	   USER_IN              VARCHAR2(100) NOT NULL,
       USER_UP              VARCHAR2(100),
       USER_DE              VARCHAR2(100),
       TIME_IN              TIMESTAMP NOT NULL,
       TIME_UP              TIMESTAMP DEFAULT NULL,
       TIME_DE              TIMESTAMP DEFAULT NULL,
       SBI_VERSION_IN       VARCHAR2(10),
       SBI_VERSION_UP       VARCHAR2(10),
       SBI_VERSION_DE       VARCHAR2(10),
       META_VERSION         VARCHAR2(100),
       ORGANIZATION         VARCHAR2(20),
       CONSTRAINT XAK1SBI_CACHE_ITEM UNIQUE(TABLE_NAME),
	   PRIMARY KEY (SIGNATURE)
);


CREATE TABLE SBI_OBJ_DATA_SET (
    BIOBJ_DS_ID INTEGER NOT NULL,
    BIOBJ_ID INTEGER NOT NULL,
    DS_ID INTEGER NOT NULL,
    IS_DETAIL SMALLINT DEFAULT 0,
    USER_IN VARCHAR2(100) NOT NULL,
    USER_UP VARCHAR2(100) NULL,
    USER_DE VARCHAR2(100) ,
    TIME_IN TIMESTAMP,
    TIME_UP TIMESTAMP NULL ,
    TIME_DE TIMESTAMP NULL ,
    SBI_VERSION_IN VARCHAR2(10) NULL,
    SBI_VERSION_UP VARCHAR2(10) NULL,
    SBI_VERSION_DE VARCHAR2(10) NULL,
    META_VERSION VARCHAR2(100) NULL,
    ORGANIZATION VARCHAR2(20) NULL,
    CONSTRAINT XAK1SBI_OBJ_DATA_SET UNIQUE (BIOBJ_ID ,DS_ID, ORGANIZATION),
  PRIMARY KEY (BIOBJ_DS_ID)
);

CREATE TABLE SBI_FEDERATION_DEFINITION (
	   FEDERATION_ID 		INTEGER NOT NULL,
  	   LABEL 				VARCHAR(100) NOT NULL,
       NAME 				VARCHAR(100) NOT NULL,
       DESCRIPTION 			VARCHAR(100) DEFAULT NULL,
       RELATIONSHIPS 		VARCHAR2(4000),
       DEGENERATED			CHAR(1),
	   OWNER 				VARCHAR(100) NOT NULL,
       USER_IN 				VARCHAR(100) NOT NULL,
       USER_UP 				VARCHAR(100),
       USER_DE 				VARCHAR(100),
       TIME_IN 				TIMESTAMP NOT NULL,
       TIME_UP 				TIMESTAMP DEFAULT NULL,
       TIME_DE 				TIMESTAMP DEFAULT NULL,
       SBI_VERSION_IN 		VARCHAR(10),
       SBI_VERSION_UP 		VARCHAR(10),
       SBI_VERSION_DE 		VARCHAR(10),
       META_VERSION 		VARCHAR(100),
       ORGANIZATION 		VARCHAR(20),
  	   PRIMARY KEY (FEDERATION_ID)
);

CREATE TABLE SBI_DATA_SET_FEDERATION (
       FEDERATION_ID 		INTEGER NOT NULL,
       DS_ID 				INTEGER NOT NULL,
       VERSION_NUM 			INTEGER NOT NULL,
       ORGANIZATION 		VARCHAR(20) NOT NULL,
       PRIMARY KEY (FEDERATION_ID,DS_ID,VERSION_NUM,ORGANIZATION)
);

-- tables for different knowage product types
CREATE TABLE SBI_PRODUCT_TYPE (
	PRODUCT_TYPE_ID 		INTEGER NOT NULL,
	LABEL 					VARCHAR(40) NOT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY(PRODUCT_TYPE_ID),
	CONSTRAINT XAK1SBI_PRODUCT_TYPE UNIQUE (LABEL, ORGANIZATION)
);



-- mapping table between organizations (tenants) and product types
CREATE TABLE SBI_ORGANIZATION_PRODUCT_TYPE (
	PRODUCT_TYPE_ID 		INTEGER NOT NULL,
	ORGANIZATION_ID 		INTEGER NOT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY(PRODUCT_TYPE_ID, ORGANIZATION_ID)
);



-- create: GLOSSARY tables
CREATE TABLE SBI_GL_WORD (
	WORD_ID 				INTEGER NOT NULL,
	WORD 					VARCHAR (100),
	DESCR 					VARCHAR (500),
	FORMULA 				VARCHAR (500),
	STATE 					INTEGER DEFAULT NULL,
	CATEGORY 				INTEGER DEFAULT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY(WORD_ID)
);


CREATE TABLE SBI_GL_ATTRIBUTES (
	ATTRIBUTE_ID 			INTEGER NOT NULL,
	ATTRIBUTE_CD 			VARCHAR (30),
	ATTRIBUTE_NM 			VARCHAR (100),
	ATTRIBUTE_DS 			VARCHAR (500),
	MANDATORY_FL 			INTEGER,
	ATTRIBUTES_TYPE 		VARCHAR (50),
	DOMAIN 					VARCHAR (500),
	FORMAT 					VARCHAR (30),
	DISPLAY_TP 				VARCHAR (30),
	ATTRIBUTES_ORDER 		VARCHAR (30),
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY(ATTRIBUTE_ID)
);


CREATE TABLE SBI_GL_WORD_ATTR (
	WORD_ID 				INTEGER NOT NULL,
	ATTRIBUTE_ID 			INTEGER NOT NULL,
	ATTR_VALUE 				VARCHAR (500),
	ATTR_ORDER 				INTEGER,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY(WORD_ID,ATTRIBUTE_ID)
);


CREATE TABLE SBI_GL_REFERENCES (
	WORD_ID					INTEGER NOT NULL,
	REF_WORD_ID 			INTEGER NOT NULL,
	REFERENCES_ORDER 		INTEGER,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY(WORD_ID,REF_WORD_ID)
);


CREATE TABLE SBI_GL_GLOSSARY (
	GLOSSARY_ID 			INTEGER NOT NULL,
	GLOSSARY_CD 			VARCHAR (30),
	GLOSSARY_NM 			VARCHAR (100),
	GLOSSARY_DS 			VARCHAR (500),
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY(GLOSSARY_ID)
);


CREATE TABLE SBI_GL_CONTENTS (
	CONTENT_ID 				INTEGER NOT NULL,
	GLOSSARY_ID 			INTEGER NOT NULL,
	PARENT_ID				INTEGER,
	CONTENT_CD 				VARCHAR (30),
	CONTENT_NM 				VARCHAR (100),
	CONTENT_DS 				VARCHAR (500),
	DEPTH 					INTEGER,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY(CONTENT_ID)
);



CREATE TABLE SBI_GL_WLIST (
	CONTENT_ID 				INTEGER NOT NULL,
	WORD_ID 				INTEGER NOT NULL,
	WORD_ORDER 				INTEGER,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY(CONTENT_ID,WORD_ID)
);


CREATE TABLE SBI_PRODUCT_TYPE_ENGINE (
	PRODUCT_TYPE_ID 		INTEGER NOT NULL,
	ENGINE_ID 				INTEGER NOT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY (PRODUCT_TYPE_ID, ENGINE_ID)
);


CREATE TABLE SBI_IMAGES (
	IMAGE_ID 				INTEGER NOT NULL,
	NAME 					VARCHAR(100) NOT NULL,
	CONTENT 				BLOB NOT NULL,
	CONTENT_ICO 			BLOB,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY (IMAGE_ID),
	CONSTRAINT NAME_UNIQUE UNIQUE (NAME, ORGANIZATION)
);


CREATE TABLE SBI_GL_DOCWLIST (
	WORD_ID 				INTEGER NOT NULL,
	BIOBJ_ID 				INTEGER NOT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY (BIOBJ_ID, WORD_ID)
);


CREATE TABLE SBI_GL_DATASETWLIST (
	WORD_ID 					INTEGER NOT NULL,
	DS_ID 					INTEGER NOT NULL,
	COLUMN_NAME 				VARCHAR(100) NOT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	 VERSION_NUM INTEGER DEFAULT NULL,
	 PRIMARY KEY (WORD_ID,DS_ID,COLUMN_NAME)
);


CREATE TABLE SBI_GL_BNESS_CLS_WLIST (
	WORD_ID 				INTEGER NOT NULL,
	BC_ID 					INTEGER NOT NULL,
	COLUMN_NAME 			VARCHAR(100) DEFAULT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY (BC_ID, WORD_ID, COLUMN_NAME)
);


CREATE TABLE SBI_GL_TABLE_WLIST (
	WORD_ID 				INTEGER NOT NULL,
	TABLE_ID 				INTEGER NOT NULL,
	COLUMN_NAME				VARCHAR(100) NOT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY (TABLE_ID, WORD_ID, COLUMN_NAME)
);


CREATE TABLE SBI_WS_EVENT (
	ID 						INTEGER NOT NULL,
	EVENT_NAME 				VARCHAR(80) NOT NULL,
	IP_COME_FROM 			VARCHAR(15) NULL,
	INCOMING_DATE 			TIMESTAMP NULL,
	TAKE_CHARGE_DATE 		TIMESTAMP NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY (id)
);


/* CROSS NAVIGATION */
CREATE TABLE SBI_CROSS_NAVIGATION (
	ID 						INTEGER NOT NULL,
	NAME 					VARCHAR(40) NOT NULL,
	DESCRIPTION				VARCHAR2(200) NULL,
	BREADCRUMB				VARCHAR2(200) NULL,
	TYPE 					INTEGER NOT NULL,
	POPUP_OPTIONS           VARCHAR(4000)  DEFAULT NULL,
	TO_DOC_ID               INTEGER DEFAULT NULL,
	FROM_DOC_ID             INTEGER DEFAULT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY (ID),
	CONSTRAINT "XAK1SBI_CROSS_NAVIGATION" UNIQUE ("NAME", "ORGANIZATION")
);


CREATE TABLE SBI_CROSS_NAVIGATION_PAR (
	ID 						INTEGER NOT NULL,
	CN_ID 					INTEGER NOT NULL,
	FROM_KEY 				INTEGER NOT NULL,
	TO_KEY 					INTEGER NOT NULL,
	FROM_TYPE 				INTEGER NOT NULL,
	FIXED_VALUE 			VARCHAR(100) NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY (ID)
);


/* OUTPUT PARAMETER*/
CREATE TABLE SBI_OUTPUT_PARAMETER (
	ID 						INTEGER NOT NULL,
	BIOBJ_ID				INTEGER NOT NULL,
	LABEL 					VARCHAR(40) NOT NULL,
	PAR_TYPE_ID 			INTEGER NOT NULL,
	FORMAT_CODE 			VARCHAR(20) NULL,
	FORMAT_VALUE 			VARCHAR(30) NULL,
	IS_USER_DEFINED         SMALLINT    DEFAULT 0,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY (ID)
);


---- TIMESPAN
CREATE TABLE SBI_TIMESPAN (
	ID 						INTEGER NOT NULL,
	NAME 					VARCHAR(45) NOT NULL,
	TYPE 					VARCHAR(45) NOT NULL,
	CATEGORY 				VARCHAR(45) DEFAULT NULL,
	STATIC_FILTER 			NUMBER(1) DEFAULT 0,
	DEFINITION 				VARCHAR(4000) DEFAULT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY (ID)
);


CREATE TABLE SBI_ROLES_LAYERS (
	ID_LAYER 				INTEGER NOT NULL,
	ID_ROLE 				INTEGER NOT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY (ID_LAYER,ID_ROLE)
);


CREATE TABLE SBI_KPI_ALIAS (
	ID 						INTEGER NOT NULL,
	NAME 					VARCHAR(40) NOT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY (ID)
);


CREATE TABLE SBI_KPI_RULE (
	ID 						INTEGER NOT NULL,
	VERSION					INTEGER NOT NULL,
	NAME 					VARCHAR(40) NOT NULL,
	DEFINITION 				VARCHAR(4000) NOT NULL,
	DATASOURCE_ID 			INTEGER NOT NULL,
	ACTIVE                  CHAR(1),
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY (ID,VERSION)
);


CREATE TABLE SBI_KPI_KPI (
	ID 						INTEGER NOT NULL,
	VERSION					INTEGER NOT NULL,
	NAME 					VARCHAR(40) NOT NULL,
	DEFINITION 				VARCHAR(4000) NOT NULL,
	CARDINALITY 			VARCHAR(4000) NOT NULL,
	PLACEHOLDER 			VARCHAR(1024) NULL,
	CATEGORY_ID 			INTEGER NULL,
	THRESHOLD_ID 			INTEGER NOT NULL,
	ACTIVE                  CHAR(1),
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY (ID,VERSION)
);


CREATE TABLE SBI_KPI_PLACEHOLDER (
	ID 						INTEGER NOT NULL,
	NAME 					VARCHAR(40) NOT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY (ID)
);


CREATE TABLE SBI_KPI_THRESHOLD (
	ID 						INTEGER NOT NULL,
	NAME 					VARCHAR(40) NOT NULL,
	DESCRIPTION 			VARCHAR(1024),
	TYPE_ID 				INTEGER DEFAULT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY (ID)
);


CREATE TABLE SBI_KPI_THRESHOLD_VALUE (
	ID 						INTEGER NOT NULL,
	THRESHOLD_ID 			INTEGER NOT NULL,
	POSITION_NUMBER 		INTEGER DEFAULT NULL,
	LABEL 					VARCHAR(40) DEFAULT NULL,
	MIN_VALUE 				NUMBER(18,5) DEFAULT NULL,
	INCLUDE_MIN 			CHAR (1) DEFAULT NULL,
	MAX_VALUE 				NUMBER(18,5) DEFAULT NULL,
	INCLUDE_MAX 			CHAR (1) DEFAULT NULL,
	COLOR 					VARCHAR(20) DEFAULT NULL,
	SEVERITY_ID 			INTEGER DEFAULT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY (ID)
);


CREATE TABLE SBI_KPI_RULE_OUTPUT (
	ID 						INTEGER NOT NULL,
	RULE_ID 				INTEGER NOT NULL,
	RULE_VERSION			INTEGER NOT NULL,
	TYPE_ID 				INTEGER NOT NULL,
	ALIAS_ID 				INTEGER NOT NULL,
	CATEGORY_ID 			INTEGER NULL,
	HIERARCHY_ID 			INTEGER NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY (ID)
);


CREATE TABLE SBI_KPI_KPI_RULE_OUTPUT (
  KPI_ID 					INTEGER NOT NULL,
  KPI_VERSION 				INTEGER NOT NULL,
  RULE_OUTPUT_ID 			INTEGER NOT NULL,
  PRIMARY KEY (KPI_ID,KPI_VERSION,RULE_OUTPUT_ID)
);


CREATE TABLE SBI_KPI_RULE_PLACEHOLDER (
	RULE_ID 				INTEGER NOT NULL,
	RULE_VERSION			INTEGER NOT NULL,
	PLACEHOLDER_ID 			INTEGER NOT NULL,

	PRIMARY KEY (RULE_ID,RULE_VERSION,PLACEHOLDER_ID)
);


CREATE TABLE SBI_KPI_TARGET (
	TARGET_ID				INTEGER NOT NULL,
	NAME 					VARCHAR(40),
	CATEGORY_ID 			INTEGER DEFAULT NULL,
	START_VALIDITY_DAY		TIMESTAMP DEFAULT NULL,
	END_VALIDITY_DAY		TIMESTAMP DEFAULT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	CONSTRAINT XAK1SBI_KPI_TARGET UNIQUE (NAME, ORGANIZATION),
	PRIMARY KEY (TARGET_ID)
);


CREATE TABLE SBI_KPI_TARGET_VALUE (
	TARGET_ID			INTEGER NOT NULL,
	KPI_ID 				INTEGER NOT NULL,
	KPI_VERSION			INTEGER NOT NULL,
	TARGET_VALUE		NUMBER(10,5),
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
	PRIMARY KEY (TARGET_ID,KPI_ID,KPI_VERSION)
);


CREATE TABLE SBI_KPI_EXECUTION_KPI (
    KPI_ID                 	INTEGER NOT NULL,
    KPI_VERSION            	INTEGER NOT NULL,
    EXECUTION_ID        	INTEGER NOT NULL,
    PRIMARY KEY (KPI_ID, KPI_VERSION, EXECUTION_ID)
);


CREATE TABLE SBI_KPI_SCORECARD_KPI (
    KPI_ID                 INTEGER NOT NULL,
    KPI_VERSION            INTEGER NOT NULL,
    SCORECARD_ID           INTEGER NOT NULL,
    PRIMARY KEY (KPI_ID, KPI_VERSION, SCORECARD_ID)
);


CREATE TABLE SBI_KPI_EXECUTION_FILTER (
  	PLACEHOLDER_ID 			INTEGER NOT NULL,
  	EXECUTION_ID 			INTEGER NOT NULL,
  	KPI_ID 					INTEGER NOT NULL,
  	KPI_VERSION 			INTEGER NOT NULL,
  	TYPE_ID 				INTEGER DEFAULT NULL,
  	VALUE 					VARCHAR(40) DEFAULT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
  	PRIMARY KEY (PLACEHOLDER_ID,EXECUTION_ID,KPI_ID,KPI_VERSION)
);


CREATE TABLE SBI_KPI_EXECUTION (
  	ID 						INTEGER NOT NULL,
  	NAME					VARCHAR(40) NOT NULL,
  	START_DATE 				TIMESTAMP NOT NULL,
  	END_DATE 				TIMESTAMP DEFAULT NULL,
  	DELTA 					CHAR(1) DEFAULT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
  	PRIMARY KEY (ID)
);


CREATE TABLE SBI_KPI_SCORECARD (
  	ID 					INTEGER NOT NULL,
  	PARENT_ID 			INTEGER DEFAULT NULL,
  	NAME 				VARCHAR(40) NOT NULL,
  	CRITERION_ID 		INTEGER DEFAULT NULL,
  	OPTIONS 			VARCHAR(1000) DEFAULT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100),
	USER_DE 				VARCHAR(100),
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP,
	TIME_DE 				TIMESTAMP,
	SBI_VERSION_IN 			VARCHAR(10),
	SBI_VERSION_UP 			VARCHAR(10),
	SBI_VERSION_DE 			VARCHAR(10),
	META_VERSION 			VARCHAR(100),
	ORGANIZATION 			VARCHAR(20),
  	PRIMARY KEY (ID)
);


CREATE TABLE SBI_KPI_VALUE (
  	ID 					INTEGER NOT NULL,
  	KPI_ID 				INTEGER NOT NULL,
  	KPI_VERSION 		INTEGER NOT NULL,
  	LOGICAL_KEY 		VARCHAR(4000),
  	TIME_RUN 			TIMESTAMP NOT NULL,
  	COMPUTED_VALUE 		NUMBER(18,5)  NOT NULL,
  	MANUAL_VALUE 		NUMBER(18,5) ,
    MANUAL_NOTE			VARCHAR(1000) NULL,
  	THE_DAY 			VARCHAR(3) NOT NULL,
  	THE_WEEK 			VARCHAR(3) NOT NULL,
  	THE_MONTH 			VARCHAR(3) NOT NULL,
  	THE_QUARTER 		VARCHAR(3) NOT NULL,
  	THE_YEAR 			VARCHAR(4) NOT NULL,
    STATE				CHAR(1) DEFAULT '0',
    PRIMARY KEY (ID)
);


CREATE TABLE SBI_KPI_VALUE_EXEC_LOG (
	ID					INTEGER,
	SCHEDULER_ID		INTEGER NOT NULL,
	TIME_RUN			TIMESTAMP NOT NULL,
	OUTPUT				BLOB NULL,
	ERROR_COUNT			INTEGER NOT NULL,
	SUCCESS_COUNT		INTEGER NOT NULL,
	TOTAL_COUNT			INTEGER NOT NULL,
	PRIMARY KEY (ID)
);


CREATE TABLE SBI_META_SOURCE (
	SOURCE_ID 				INTEGER NOT NULL,
	NAME 					VARCHAR(100) NOT NULL,
	TYPE 					VARCHAR(100) NOT NULL,
	URL 					VARCHAR(100) NULL,
	LOCATION 				VARCHAR(100) NULL,
	SOURCE_SCHEMA 			VARCHAR(100) NULL,
	SOURCE_CATALOGUE    	VARCHAR(100) NULL,
	ROLE                    VARCHAR(100) NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100) DEFAULT NULL,
	USER_DE 				VARCHAR(100) DEFAULT NULL,
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP DEFAULT NULL,
	TIME_DE 				TIMESTAMP DEFAULT NULL,
	SBI_VERSION_IN 			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_UP 			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_DE 			VARCHAR(10) DEFAULT NULL,
	META_VERSION 			VARCHAR(100) DEFAULT NULL,
	ORGANIZATION 			VARCHAR(20) DEFAULT NULL,
	PRIMARY KEY (SOURCE_ID)
);


CREATE TABLE SBI_META_TABLE  (
	TABLE_ID 				INTEGER NOT NULL,
	SOURCE_ID 				INTEGER NOT NULL,
	NAME 					VARCHAR(100) NOT NULL,
	DELETED					SMALLINT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100) DEFAULT NULL,
	USER_DE 				VARCHAR(100) DEFAULT NULL,
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP DEFAULT NULL,
	TIME_DE 				TIMESTAMP DEFAULT NULL,
	SBI_VERSION_IN 			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_UP 			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_DE 			VARCHAR(10) DEFAULT NULL,
	META_VERSION 			VARCHAR(100) DEFAULT NULL,
	ORGANIZATION 			VARCHAR(20) DEFAULT NULL,
	PRIMARY KEY (TABLE_ID)
);


CREATE TABLE SBI_META_TABLE_COLUMN  (
	COLUMN_ID 				INTEGER NOT NULL,
	TABLE_ID 				INTEGER NOT NULL,
	NAME 					VARCHAR(100) NOT NULL,
	TYPE					VARCHAR(100) NOT NULL,
	DELETED					SMALLINT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100) DEFAULT NULL,
	USER_DE 				VARCHAR(100) DEFAULT NULL,
	TIME_IN 				TIMESTAMP,
	TIME_UP 				TIMESTAMP DEFAULT NULL,
	TIME_DE 				TIMESTAMP DEFAULT NULL,
	SBI_VERSION_IN 			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_UP 			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_DE 			VARCHAR(10) DEFAULT NULL,
	META_VERSION 			VARCHAR(100) DEFAULT NULL,
	ORGANIZATION 			VARCHAR(20) DEFAULT NULL,
	PRIMARY KEY (COLUMN_ID)
);


CREATE TABLE SBI_META_BC  (
	BC_ID 					INTEGER NOT NULL,
	MODEL_ID				INTEGER NOT NULL,
	NAME					VARCHAR(100) NOT NULL,
	UNIQUE_NAME				VARCHAR(100),
	DELETED					SMALLINT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100) DEFAULT NULL,
	USER_DE 				VARCHAR(100) DEFAULT NULL,
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP DEFAULT NULL,
	TIME_DE 				TIMESTAMP DEFAULT NULL,
	SBI_VERSION_IN 			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_UP 			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_DE 			VARCHAR(10) DEFAULT NULL,
	META_VERSION 			VARCHAR(100) DEFAULT NULL,
	ORGANIZATION 			VARCHAR(20) DEFAULT NULL,
	PRIMARY KEY (BC_ID)
);


CREATE TABLE SBI_META_BC_ATTRIBUTE  (
	ATTRIBUTE_ID 			INTEGER NOT NULL,
	BC_ID					INTEGER NULL,
	COLUMN_ID				INTEGER NULL,
	NAME					VARCHAR(100) NOT NULL,
	TYPE					VARCHAR(100) NULL,
	DELETED					SMALLINT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100) DEFAULT NULL,
	USER_DE 				VARCHAR(100) DEFAULT NULL,
	TIME_IN 				TIMESTAMP,
	TIME_UP 				TIMESTAMP DEFAULT NULL,
	TIME_DE 				TIMESTAMP DEFAULT NULL,
	SBI_VERSION_IN 			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_UP 			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_DE 			VARCHAR(10) DEFAULT NULL,
	META_VERSION 			VARCHAR(100) DEFAULT NULL,
	ORGANIZATION 			VARCHAR(20) DEFAULT NULL,
	PRIMARY KEY (ATTRIBUTE_ID)
);


CREATE TABLE SBI_META_TABLE_BC  (
	TABLE_ID 				INTEGER NOT NULL,
	BC_ID 					INTEGER NOT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100) DEFAULT NULL,
	USER_DE 				VARCHAR(100) DEFAULT NULL,
	TIME_IN 				TIMESTAMP,
	TIME_UP 				TIMESTAMP DEFAULT NULL,
	TIME_DE 				TIMESTAMP DEFAULT NULL,
	SBI_VERSION_IN 			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_UP 			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_DE 			VARCHAR(10) DEFAULT NULL,
	META_VERSION 			VARCHAR(100) DEFAULT NULL,
	ORGANIZATION 			VARCHAR(20) DEFAULT NULL,
	PRIMARY KEY (TABLE_ID, BC_ID)
);


CREATE TABLE SBI_META_DS_BC  (
	DS_ID 					INTEGER NOT NULL,
	VERSION_NUM				INTEGER NOT NULL,
	BC_ID 					INTEGER NOT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100) DEFAULT NULL,
	USER_DE 				VARCHAR(100) DEFAULT NULL,
	TIME_IN 				TIMESTAMP NOT NULL,
	TIME_UP 				TIMESTAMP DEFAULT NULL,
	TIME_DE 				TIMESTAMP DEFAULT NULL,
	SBI_VERSION_IN 			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_UP 			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_DE 			VARCHAR(10) DEFAULT NULL,
	META_VERSION 			VARCHAR(100) DEFAULT NULL,
	ORGANIZATION 			VARCHAR(20)  NOT NULL,
	PRIMARY KEY (DS_ID,VERSION_NUM,ORGANIZATION,BC_ID)
);


CREATE TABLE SBI_META_OBJ_DS  (
	DS_ID 					INTEGER NOT NULL,
	VERSION_NUM				INTEGER NOT NULL,
	OBJ_ID 					INTEGER NOT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100) DEFAULT NULL,
	USER_DE 				VARCHAR(100) DEFAULT NULL,
	TIME_IN 				TIMESTAMP,
	TIME_UP 				TIMESTAMP DEFAULT NULL,
	TIME_DE 				TIMESTAMP DEFAULT NULL,
	SBI_VERSION_IN 			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_UP 			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_DE 			VARCHAR(10) DEFAULT NULL,
	META_VERSION 			VARCHAR(100) DEFAULT NULL,
	ORGANIZATION 			VARCHAR(20)  NOT NULL,
	PRIMARY KEY (DS_ID,VERSION_NUM,ORGANIZATION,OBJ_ID)
);


CREATE TABLE SBI_META_JOB  (
	JOB_ID 					INTEGER NOT NULL,
	NAME					VARCHAR(100) NOT NULL,
	DELETED					SMALLINT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100) DEFAULT NULL,
	USER_DE 				VARCHAR(100) DEFAULT NULL,
	TIME_IN 				TIMESTAMP,
	TIME_UP 				TIMESTAMP DEFAULT NULL,
	TIME_DE 				TIMESTAMP DEFAULT NULL,
	SBI_VERSION_IN 			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_UP 			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_DE 			VARCHAR(10) DEFAULT NULL,
	META_VERSION 			VARCHAR(100) DEFAULT NULL,
	ORGANIZATION 			VARCHAR(20) DEFAULT NULL,
	PRIMARY KEY (JOB_ID)
);



CREATE TABLE SBI_META_JOB_SOURCE  (
	JOB_ID					INTEGER NOT NULL,
	SOURCE_ID				INTEGER NOT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100) DEFAULT NULL,
	USER_DE 				VARCHAR(100) DEFAULT NULL,
	TIME_IN 				TIMESTAMP,
	TIME_UP 				TIMESTAMP DEFAULT NULL,
	TIME_DE 				TIMESTAMP DEFAULT NULL,
	SBI_VERSION_IN 			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_UP 			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_DE 			VARCHAR(10) DEFAULT NULL,
	META_VERSION 			VARCHAR(100) DEFAULT NULL,
	ORGANIZATION 			VARCHAR(20) DEFAULT NULL,
	PRIMARY KEY (JOB_ID, SOURCE_ID)
);


CREATE TABLE SBI_META_JOB_TABLE  (
	JOB_ID					INTEGER NOT NULL,
	TABLE_ID				INTEGER NOT NULL,
	ROLE					VARCHAR(100) NOT NULL,
	USER_IN 				VARCHAR(100) NOT NULL,
	USER_UP 				VARCHAR(100) DEFAULT NULL,
	USER_DE 				VARCHAR(100) DEFAULT NULL,
	TIME_IN 				TIMESTAMP,
	TIME_UP 				TIMESTAMP DEFAULT NULL,
	TIME_DE 				TIMESTAMP DEFAULT NULL,
	SBI_VERSION_IN 			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_UP 			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_DE 			VARCHAR(10) DEFAULT NULL,
	META_VERSION 			VARCHAR(100) DEFAULT NULL,
	ORGANIZATION 			VARCHAR(20) DEFAULT NULL,
	PRIMARY KEY (JOB_ID,TABLE_ID)
);
--TODO
CREATE TABLE SBI_META_DATASET_REL (
  DS_TABLE_REL_ID  INTEGER NOT NULL,
  DATASET_ID  INTEGER NOT NULL,
  TABLE_ID  INTEGER NOT NULL,
  USER_IN  VARCHAR(100) NOT NULL,
  USER_UP  VARCHAR(100) DEFAULT NULL,
  USER_DE  VARCHAR(100) DEFAULT NULL,
  TIME_IN  TIMESTAMP,
  TIME_UP  TIMESTAMP DEFAULT NULL,
  TIME_DE  TIMESTAMP DEFAULT NULL,
  SBI_VERSION_IN  VARCHAR(10) DEFAULT NULL,
  SBI_VERSION_UP  VARCHAR(10) DEFAULT NULL,
  SBI_VERSION_DE  VARCHAR(10) DEFAULT NULL,
  META_VERSION  VARCHAR(100) DEFAULT NULL,
  ORGANIZATION  VARCHAR(20) DEFAULT NULL,
  PRIMARY KEY (DS_TABLE_REL_ID)
);

CREATE TABLE SBI_META_DOCUMENT_REL(
  DOC_TABLE_REL_ID  INTEGER NOT NULL,
  DOCUMENT_ID  INTEGER NOT NULL,
  TABLE_ID INTEGER NOT NULL,
  USER_IN  VARCHAR(100) NOT NULL,
  USER_UP  VARCHAR(100) DEFAULT NULL,
  USER_DE  VARCHAR(100) DEFAULT NULL,
  TIME_IN  TIMESTAMP,
  TIME_UP  TIMESTAMP DEFAULT NULL,
  TIME_DE  TIMESTAMP DEFAULT NULL,
  SBI_VERSION_IN  VARCHAR(10) DEFAULT NULL,
  SBI_VERSION_UP  VARCHAR(10) DEFAULT NULL,
  SBI_VERSION_DE  VARCHAR(10) DEFAULT NULL,
  META_VERSION  VARCHAR(100) DEFAULT NULL,
  ORGANIZATION  VARCHAR(20) DEFAULT NULL,
  PRIMARY KEY (DOC_TABLE_REL_ID)
);


CREATE TABLE SBI_ALERT_ACTION (
	ID 					INTEGER NOT NULL,
    NAME 				VARCHAR(40) NOT NULL,
    CLASS_NAME 			VARCHAR(200) NOT NULL,
    TEMPLATE			VARCHAR(200) NOT NULL,
	USER_IN 			VARCHAR(100) NOT NULL,
	USER_UP 			VARCHAR(100),
	USER_DE 			VARCHAR(100),
	TIME_IN 			TIMESTAMP NOT NULL,
	TIME_UP 			TIMESTAMP,
	TIME_DE 			TIMESTAMP,
	SBI_VERSION_IN 		VARCHAR(10),
	SBI_VERSION_UP 		VARCHAR(10),
	SBI_VERSION_DE 		VARCHAR(10),
	META_VERSION 		VARCHAR(100),
	ORGANIZATION 		VARCHAR(20),
	PRIMARY KEY(ID)
);

CREATE TABLE SBI_ALERT_LISTENER (
	ID 					INTEGER NOT NULL,
    NAME 				VARCHAR(40) NOT NULL,
    CLASS_NAME 			VARCHAR(200) NOT NULL,
    TEMPLATE			VARCHAR(200) NOT NULL,
	USER_IN 			VARCHAR(100) NOT NULL,
	USER_UP 			VARCHAR(100),
	USER_DE 			VARCHAR(100),
	TIME_IN 			TIMESTAMP NOT NULL,
	TIME_UP 			TIMESTAMP,
	TIME_DE 			TIMESTAMP,
	SBI_VERSION_IN 		VARCHAR(10),
	SBI_VERSION_UP 		VARCHAR(10),
	SBI_VERSION_DE 		VARCHAR(10),
	META_VERSION 		VARCHAR(100),
	ORGANIZATION 		VARCHAR(20),
	PRIMARY KEY(ID)
);

CREATE TABLE SBI_ALERT (
	ID 					INTEGER NOT NULL,
	NAME 				VARCHAR(40) NOT NULL,
	SINGLE_EXECUTION    VARCHAR2(1),
	EVENT_BEFORE_TRIGGER_ACTION INTEGER,
	LISTENER_ID			INTEGER NOT NULL,
	LISTENER_OPTIONS    VARCHAR(4000),
	USER_IN 			VARCHAR(100) NOT NULL,
	USER_UP 			VARCHAR(100),
	USER_DE 			VARCHAR(100),
	TIME_IN 			TIMESTAMP NOT NULL,
	TIME_UP 			TIMESTAMP,
	TIME_DE 			TIMESTAMP,
	SBI_VERSION_IN 		VARCHAR(10),
	SBI_VERSION_UP 		VARCHAR(10),
	SBI_VERSION_DE 		VARCHAR(10),
	META_VERSION 		VARCHAR(100),
	ORGANIZATION 		VARCHAR(20),
	PRIMARY KEY(ID)
);

CREATE TABLE SBI_ALERT_LOG (
	ID					INTEGER NOT NULL,
    LISTENER_ID		 	INTEGER NOT NULL,
    ACTION_ID			INTEGER,
    LISTENER_PARAMS		VARCHAR(4000),
    ACTION_PARAMS		VARCHAR(4000),
    DETAIL				VARCHAR(4000),
    USER_IN 			VARCHAR(100) NOT NULL,
	USER_UP 			VARCHAR(100),
	USER_DE 			VARCHAR(100),
	TIME_IN 			TIMESTAMP NOT NULL,
	TIME_UP 			TIMESTAMP,
	TIME_DE 			TIMESTAMP,
	SBI_VERSION_IN 		VARCHAR(10),
	SBI_VERSION_UP 		VARCHAR(10),
	SBI_VERSION_DE 		VARCHAR(10),
	META_VERSION 		VARCHAR(100),
	ORGANIZATION 		VARCHAR(20),
    PRIMARY KEY(ID)
);

CREATE TABLE SBI_CATALOG_FUNCTION (
	FUNCTION_UUID			VARCHAR(36) NOT NULL,
	NAME					VARCHAR(100) NOT NULL,
	DESCRIPTION				CLOB NOT NULL,
	BENCHMARKS				CLOB,
	LANGUAGE				VARCHAR(100) NOT NULL,
	FAMILY					VARCHAR(30) NOT NULL,
	ONLINE_SCRIPT			CLOB,
	OFFLINE_SCRIPT_TRAIN	CLOB,
	OFFLINE_SCRIPT_USE		CLOB,
	OWNER					VARCHAR(50) NOT NULL,
	KEYWORDS				VARCHAR(255) DEFAULT NULL,
	TYPE					VARCHAR(50) DEFAULT NULL,
	LABEL					VARCHAR(50) NOT NULL,
	USER_IN					VARCHAR(100) NOT NULL,
	USER_UP					VARCHAR(100) DEFAULT NULL,
	USER_DE					VARCHAR(100) DEFAULT NULL,
	TIME_IN					TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
	TIME_UP					TIMESTAMP DEFAULT NULL,
	TIME_DE					TIMESTAMP DEFAULT NULL,
	SBI_VERSION_IN			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_UP			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_DE			VARCHAR(10) DEFAULT NULL,
	ORGANIZATION			VARCHAR(20) NOT NULL,
	CONSTRAINT UNIQUE_LABEL_ORG UNIQUE (LABEL, ORGANIZATION),
	CONSTRAINT UNIQUE_FUNC_ID_ORG UNIQUE (FUNCTION_UUID,ORGANIZATION),
	PRIMARY KEY (FUNCTION_UUID)
);

CREATE TABLE SBI_FUNCTION_INPUT_VARIABLE (
	FUNCTION_UUID 		VARCHAR(36) NOT NULL,
	VAR_NAME			VARCHAR(100) NOT NULL,
	VAR_VALUE 			VARCHAR(100) NOT NULL,
	VAR_TYPE 			VARCHAR(100) NOT NULL,
	USER_IN				VARCHAR(100) NOT NULL,
	USER_UP				VARCHAR(100) DEFAULT NULL,
	USER_DE				VARCHAR(100) DEFAULT NULL,
	TIME_IN				TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
	TIME_UP				TIMESTAMP DEFAULT NULL,
	TIME_DE				TIMESTAMP DEFAULT NULL,
	SBI_VERSION_IN		VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_UP		VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_DE 		VARCHAR(10) DEFAULT NULL,
	ORGANIZATION		VARCHAR(20) NOT NULL,
	PRIMARY KEY (FUNCTION_UUID,VAR_NAME,ORGANIZATION)
);

CREATE TABLE SBI_FUNCTION_INPUT_COLUMN (
	FUNCTION_UUID			VARCHAR(36) NOT NULL,
	COL_NAME				VARCHAR(100) NOT NULL,
	COL_TYPE				VARCHAR(100) NOT NULL,
	USER_IN					VARCHAR(100) NOT NULL,
	USER_UP					VARCHAR(100) DEFAULT NULL,
	USER_DE					VARCHAR(100) DEFAULT NULL,
	TIME_IN					TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
	TIME_UP					TIMESTAMP DEFAULT NULL,
	TIME_DE					TIMESTAMP DEFAULT NULL,
	SBI_VERSION_IN			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_UP			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_DE			VARCHAR(10) DEFAULT NULL,
	ORGANIZATION			VARCHAR(20) NOT NULL,
	PRIMARY KEY (FUNCTION_UUID,COL_NAME,ORGANIZATION)
);

CREATE TABLE SBI_FUNCTION_OUTPUT_COLUMN (
	FUNCTION_UUID			VARCHAR(36) NOT NULL,
	COL_NAME				VARCHAR(100) NOT NULL,
	COL_TYPE				VARCHAR(100) NOT NULL,
	COL_FIELD_TYPE			VARCHAR(100) NOT NULL,
	USER_IN					VARCHAR(100) NOT NULL,
	USER_UP					VARCHAR(100) DEFAULT NULL,
	USER_DE					VARCHAR(100) DEFAULT NULL,
	TIME_IN					TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
	TIME_UP					TIMESTAMP DEFAULT NULL,
	TIME_DE					TIMESTAMP DEFAULT NULL,
	SBI_VERSION_IN			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_UP			VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_DE			VARCHAR(10) DEFAULT NULL,
	ORGANIZATION			VARCHAR(20) NOT NULL,
	PRIMARY KEY (FUNCTION_UUID,COL_NAME,ORGANIZATION)
);

CREATE TABLE SBI_FUNCTIONS_ORGANIZER (
	FUNCT_ID INTEGER NOT NULL ,
	PARENT_FUNCT_ID INTEGER,
	NAME VARCHAR2 (40),
	DESCR VARCHAR2 (160),
	PATH VARCHAR2 (400),
	CODE VARCHAR2 (40) NOT NULL ,
	PROG INTEGER NOT NULL ,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
CONSTRAINT XAK1SBI_FUNCTIONS_ORGANIZER UNIQUE (CODE, USER_IN),
PRIMARY KEY (FUNCT_ID)
);

CREATE TABLE SBI_OBJ_FUNC_ORGANIZER (
	BIOBJ_ID INTEGER NOT NULL ,
	FUNCT_ID INTEGER NOT NULL ,
	PROG INTEGER,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
PRIMARY KEY (BIOBJ_ID,FUNCT_ID)
);

CREATE TABLE SBI_WHATIF_WORKFLOW(
	ID INTEGER,
    MODEL_ID INTEGER,
    USER_ID INTEGER,
    SEQUENCE INTEGER,
    STATE VARCHAR2(20),
    NOTES VARCHAR2(100),
    INFO VARCHAR2(100),
    USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP VARCHAR2(100),
    USER_DE VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP              TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN VARCHAR2(10),
    SBI_VERSION_UP VARCHAR2(10),
    SBI_VERSION_DE VARCHAR2(10),
    ORGANIZATION VARCHAR2(20),
    PRIMARY KEY (ID)
);

CREATE TABLE SBI_ACCESSIBILITY_PREFERENCES (
	 ID INTEGER NOT NULL,
	 USER_ID INTEGER NOT NULL,
	 ENABLE_UIO NUMBER(38,0) NOT NULL,
	 ENABLE_RROBOBRAILLE NUMBER(38,0) DEFAULT NULL,
	 ENABLE_GRAPH_SONIFICATION NUMBER(38,0) DEFAULT NULL,
	 ENABLE_VOICE NUMBER(38,0) DEFAULT NULL,
	 PREFERENCES CLOB NULL,
     USER_IN VARCHAR2(100) NOT NULL,
     USER_UP VARCHAR2(100),
     USER_DE VARCHAR2(100),
	 TIME_IN TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
	 TIME_UP TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
	 TIME_DE TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
     SBI_VERSION_IN VARCHAR2(10),
     SBI_VERSION_UP VARCHAR2(10),
     SBI_VERSION_DE VARCHAR2(10),
     ORGANIZATION VARCHAR2(20),
	 PRIMARY KEY (ID)
);


CREATE TABLE SBI_DOSSIER_ACTIVITY(
		ID 					INTEGER NOT NULL,
		PROGRESS 			INTEGER NOT NULL,
		PPT					BLOB,
	    DOCUMENT_ID 		INTEGER,
	    ACTIVITY 			VARCHAR2(45) NOT NULL,
	    PARAMS 				VARCHAR2(4000),
     	USER_IN 			VARCHAR2(100) NOT NULL,
     	USER_UP 			VARCHAR2(100),
    	USER_DE				VARCHAR2(100),
		TIME_IN 			TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
	 	TIME_UP 			TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
	 	TIME_DE 			TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
     	SBI_VERSION_IN 		VARCHAR2(10),
     	SBI_VERSION_UP 		VARCHAR2(10),
     	SBI_VERSION_DE 		VARCHAR2(10),
     	ORGANIZATION 		VARCHAR2(20),
	    PRIMARY KEY (ID)
);

CREATE TABLE SBI_METAMODEL_PAR (
	METAMODEL_PAR_ID INTEGER NOT NULL ,
	PAR_ID INTEGER NOT NULL ,
	METAMODEL_ID INTEGER NOT NULL ,
	LABEL VARCHAR2 (40) NOT NULL ,
	REQ_FL SMALLINT DEFAULT 0,
	MOD_FL SMALLINT DEFAULT 0,
	VIEW_FL SMALLINT DEFAULT 1,
	MULT_FL SMALLINT DEFAULT 0,
	PROG INTEGER NOT NULL ,
	PARURL_NM VARCHAR2 (20),
	PRIORITY INTEGER,
	COL_SPAN             INTEGER,
    THICK_PERC           INTEGER,
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
    TIME_UP               TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
PRIMARY KEY (METAMODEL_PAR_ID)
);

CREATE TABLE SBI_METAMODEL_PARUSE (
	PARUSE_ID INTEGER NOT NULL,
	METAMODEL_PAR_ID INTEGER NOT NULL ,
	USE_ID INTEGER NOT NULL ,
	METAMODEL_PAR_FATHER_ID INTEGER NOT NULL ,
	FILTER_OPERATION VARCHAR2 (20) NOT NULL ,
	PROG INTEGER NOT NULL ,
	FILTER_COLUMN VARCHAR2 (30) NOT NULL ,
	PRE_CONDITION VARCHAR2 (10),
	POST_CONDITION VARCHAR2 (10),
	LOGIC_OPERATOR VARCHAR2 (10),
	USER_IN              VARCHAR2(100) NOT NULL,
    USER_UP              VARCHAR2(100),
    USER_DE              VARCHAR2(100),
    TIME_IN              TIMESTAMP NOT NULL,
     TIME_UP               TIMESTAMP DEFAULT NULL,
    TIME_DE              TIMESTAMP DEFAULT NULL,
    SBI_VERSION_IN       VARCHAR2(10),
    SBI_VERSION_UP       VARCHAR2(10),
    SBI_VERSION_DE       VARCHAR2(10),
    META_VERSION         VARCHAR2(100),
    ORGANIZATION         VARCHAR2(20),
    CONSTRAINT XAK1SBI_METAMODEL_PARUSE UNIQUE (METAMODEL_PAR_ID,USE_ID,METAMODEL_PAR_FATHER_ID,FILTER_OPERATION),
PRIMARY KEY (PARUSE_ID)
);

CREATE TABLE SBI_METAMODEL_PARVIEW (
		PARVIEW_ID                 INTEGER NOT NULL,
       METAMODEL_PAR_ID 			INTEGER NOT NULL,
   	   METAMODEL_PAR_FATHER_ID    INTEGER NOT NULL,
       OPERATION  			VARCHAR2(20) NOT NULL,
   	   COMPARE_VALUE  		VARCHAR2(200) NOT NULL,
   	   VIEW_LABEL   		VARCHAR2(50),
	     PROG INTEGER,
       USER_IN           	VARCHAR2(100) NOT NULL,
       USER_UP              VARCHAR2(100),
       USER_DE              VARCHAR2(100),
       TIME_IN              TIMESTAMP NOT NULL,
	    TIME_UP               TIMESTAMP DEFAULT NULL,
	    TIME_DE              TIMESTAMP DEFAULT NULL,
       SBI_VERSION_IN       VARCHAR2(10),
       SBI_VERSION_UP       VARCHAR2(10),
       SBI_VERSION_DE       VARCHAR2(10),
       META_VERSION         VARCHAR2(100),
       ORGANIZATION         VARCHAR2(20),
  PRIMARY KEY ( PARVIEW_ID )
);

CREATE TABLE SBI_METAMODEL_VIEWPOINTS (
	VP_ID INTEGER NOT NULL,
	METAMODEL_ID INTEGER NOT NULL,
	VP_NAME VARCHAR(40) NOT NULL,
	VP_OWNER VARCHAR(40) DEFAULT NULL,
	VP_DESC VARCHAR(160) DEFAULT NULL,
	VP_SCOPE VARCHAR(20) NOT NULL,
	VP_VALUE_PARAMS CLOB,
	VP_CREATION_DATE TIMESTAMP  DEFAULT CURRENT_TIMESTAMP,
	USER_IN VARCHAR(100) NOT NULL,
	USER_UP VARCHAR(100) DEFAULT NULL,
	USER_DE VARCHAR(100) DEFAULT NULL,
	TIME_IN TIMESTAMP  DEFAULT CURRENT_TIMESTAMP NOT NULL,
	TIME_UP TIMESTAMP  DEFAULT NULL,
	TIME_DE TIMESTAMP  DEFAULT NULL,
	SBI_VERSION_IN VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_UP VARCHAR(10) DEFAULT NULL,
	SBI_VERSION_DE VARCHAR(10) DEFAULT NULL,
	META_VERSION VARCHAR(100) DEFAULT NULL,
	ORGANIZATION VARCHAR(20) DEFAULT NULL,
	PRIMARY KEY (VP_ID)
);

CREATE TABLE SBI_NEWS (
	ID INTEGER NOT NULL ,
	NAME varchar(200) DEFAULT NULL,
	DESCRIPTION varchar(400) DEFAULT NULL,
	ACTIVE SMALLINT  DEFAULT '1',
	NEWS varchar(4000) DEFAULT NULL,
	MANUAL SMALLINT  DEFAULT '1',
	EXPIRATION_DATE TIMESTAMP DEFAULT NULL,
	USER_IN varchar(100) NOT NULL,
	USER_UP varchar(100) DEFAULT NULL,
	USER_DE varchar(100) DEFAULT NULL,
	TIME_IN TIMESTAMP NOT NULL,
	TIME_UP TIMESTAMP DEFAULT NULL,
	TIME_DE TIMESTAMP DEFAULT NULL,
	SBI_VERSION_IN varchar(10) DEFAULT NULL,
	SBI_VERSION_UP varchar(10) DEFAULT NULL,
	SBI_VERSION_DE varchar(10) DEFAULT NULL,
	META_VERSION varchar(100) DEFAULT NULL,
	ORGANIZATION varchar(20) DEFAULT NULL,
	CATEGORY_ID INTEGER  DEFAULT NULL,
	PRIMARY KEY (ID),
	CONSTRAINT FK_SBI_DOMAINS_VALUE_ID FOREIGN KEY (CATEGORY_ID) REFERENCES SBI_DOMAINS (VALUE_ID)
);

CREATE TABLE SBI_NEWS_READ (
	ID INTEGER NOT NULL,
	USER_ID varchar(100) NOT NULL,
	NEWS_ID INTEGER NOT NULL,
	USER_IN varchar(100) NOT NULL,
	USER_UP varchar(100) DEFAULT NULL,
	USER_DE varchar(100) DEFAULT NULL,
	TIME_IN TIMESTAMP NOT NULL,
	TIME_UP TIMESTAMP DEFAULT NULL,
	TIME_DE TIMESTAMP DEFAULT NULL,
	SBI_VERSION_IN varchar(10) DEFAULT NULL,
	SBI_VERSION_UP varchar(10) DEFAULT NULL,
	SBI_VERSION_DE varchar(10) DEFAULT NULL,
	META_VERSION varchar(100) DEFAULT NULL,
	ORGANIZATION varchar(20) DEFAULT NULL,
	PRIMARY KEY (ID),
	CONSTRAINT FK_SBI_NEWS_NEWS_ID FOREIGN KEY (NEWS_ID) REFERENCES SBI_NEWS (ID)
	ON DELETE CASCADE
);

CREATE TABLE SBI_NEWS_ROLES (
	NEWS_ID INTEGER NOT NULL,
	EXT_ROLE_ID INTEGER NOT NULL,
	PRIMARY KEY (NEWS_ID,EXT_ROLE_ID),
	CONSTRAINT FK_SBI_EXT_ROLES_EXT_ROLE_ID FOREIGN KEY (EXT_ROLE_ID) REFERENCES SBI_EXT_ROLES (EXT_ROLE_ID)
	ON DELETE CASCADE,
	CONSTRAINT FK_SBI_NEWS_ID FOREIGN KEY (NEWS_ID) REFERENCES SBI_NEWS (ID) ON DELETE CASCADE
);

CREATE TABLE SBI_TAG (
	TAG_ID               INTEGER NOT NULL,
	NAME                 VARCHAR(30) NOT NULL,
	USER_IN              VARCHAR(100) NOT NULL,
	USER_UP              VARCHAR(100),
	USER_DE              VARCHAR(100),
	TIME_IN              TIMESTAMP NOT NULL,
	TIME_UP              TIMESTAMP  DEFAULT NULL,
	TIME_DE              TIMESTAMP  DEFAULT NULL,
	SBI_VERSION_IN       VARCHAR(10),
	SBI_VERSION_UP       VARCHAR(10),
	SBI_VERSION_DE       VARCHAR(10),
	META_VERSION         VARCHAR(100),
	ORGANIZATION         VARCHAR(20),
	PRIMARY KEY (TAG_ID),
	CONSTRAINT XAK1SBI_TAG UNIQUE (NAME, ORGANIZATION)
);


CREATE TABLE SBI_DATA_SET_TAG (
	DS_ID                INTEGER NOT NULL,
	VERSION_NUM	     	 INTEGER NOT NULL,
	ORGANIZATION         VARCHAR(20),
	TAG_ID               INTEGER NOT NULL,
	PRIMARY KEY (DS_ID, VERSION_NUM, ORGANIZATION, TAG_ID),
	FOREIGN KEY (TAG_ID) REFERENCES SBI_TAG (TAG_ID) ,
	FOREIGN KEY (DS_ID, VERSION_NUM, ORGANIZATION) REFERENCES SBI_DATA_SET (DS_ID, VERSION_NUM, ORGANIZATION)
);

CREATE TABLE SBI_OBJ_FUNCTION (
	BIOBJ_FUNCTION_ID	INTEGER NOT NULL,
	BIOBJ_ID INTEGER	NOT NULL,
	FUNCTION_UUID		VARCHAR(36) NOT NULL,
	IS_DETAIL			SMALLINT DEFAULT 0,
	USER_IN				VARCHAR2(100) NOT NULL,
	USER_UP				VARCHAR2(100) NULL,
	USER_DE				VARCHAR2(100) ,
	TIME_IN				TIMESTAMP,
	TIME_UP				TIMESTAMP NULL ,
	TIME_DE				TIMESTAMP NULL ,
	SBI_VERSION_IN		VARCHAR2(10) NULL,
	SBI_VERSION_UP		VARCHAR2(10) NULL,
	SBI_VERSION_DE		VARCHAR2(10) NULL,
	META_VERSION		VARCHAR2(100) NULL,
	ORGANIZATION		VARCHAR2(20) NULL,
	CONSTRAINT XAK1SBI_OBJ_FUNCTION UNIQUE (BIOBJ_ID, FUNCTION_UUID, ORGANIZATION),
	PRIMARY KEY (BIOBJ_FUNCTION_ID)
);

ALTER TABLE SBI_OBJ_FUNCTION                ADD CONSTRAINT FK_SBI_OBJ_FUNCTION_1           FOREIGN KEY (BIOBJ_ID)                    REFERENCES SBI_OBJECTS         (BIOBJ_ID);
ALTER TABLE SBI_OBJ_FUNCTION                ADD CONSTRAINT FK_SBI_OBJ_FUNCTION_2           FOREIGN KEY (FUNCTION_UUID,ORGANIZATION)  REFERENCES SBI_CATALOG_FUNCTION(FUNCTION_UUID,ORGANIZATION);

CREATE TABLE SBI_COCKPIT_ASSOCIATION (
	SBI_COCKPIT_ASSOCIATION_ID INTEGER NOT NULL ,
	BIOBJ_ID INTEGER NOT NULL ,
	DS_ID_FROM INTEGER NOT NULL ,
	COLUMN_NAME_FROM VARCHAR2(50) NULL,
	DS_ID_TO INTEGER NOT NULL ,
	COLUMN_NAME_TO VARCHAR2(50) NULL,
	USER_IN VARCHAR2(100) NOT NULL ENABLE, 
	USER_UP VARCHAR2(100), 
	USER_DE VARCHAR2(100), 
	TIME_IN TIMESTAMP (6) NOT NULL ENABLE, 
	TIME_UP TIMESTAMP (6) DEFAULT NULL, 
	TIME_DE TIMESTAMP (6) DEFAULT NULL, 
	SBI_VERSION_IN VARCHAR2(10), 
	SBI_VERSION_UP VARCHAR2(10), 
	SBI_VERSION_DE VARCHAR2(10), 
	META_VERSION VARCHAR2(100), 
	ORGANIZATION VARCHAR2(20),
	PRIMARY KEY (SBI_COCKPIT_ASSOCIATION_ID)
);
ALTER TABLE SBI_COCKPIT_ASSOCIATION ADD CONSTRAINT FK_SBI_COCKPIT_ASSOCIATION_1 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID);

CREATE TABLE SBI_COCKPIT_WIDGET (
	SBI_COCKPIT_WIDGET_ID INTEGER NOT NULL ,
	BIOBJ_ID INTEGER NOT NULL ,
	TAB VARCHAR2(50) NULL,
	WIDGET_TYPE VARCHAR2(50) NULL,
	DS_ID INTEGER NULL,
	ASSOCIATIVE SMALLINT NULL,
	CACHE SMALLINT NULL,
	FILTERS SMALLINT NULL,
	USER_IN VARCHAR2(100) NOT NULL ENABLE, 
	USER_UP VARCHAR2(100), 
	USER_DE VARCHAR2(100), 
	TIME_IN TIMESTAMP (6) NOT NULL ENABLE, 
	TIME_UP TIMESTAMP (6) DEFAULT NULL, 
	TIME_DE TIMESTAMP (6) DEFAULT NULL, 
	SBI_VERSION_IN VARCHAR2(10), 
	SBI_VERSION_UP VARCHAR2(10), 
	SBI_VERSION_DE VARCHAR2(10), 
	META_VERSION VARCHAR2(100), 
	ORGANIZATION VARCHAR2(20),
	PRIMARY KEY (SBI_COCKPIT_WIDGET_ID)
);
ALTER TABLE SBI_COCKPIT_WIDGET ADD CONSTRAINT FK_SBI_COCKPIT_WIDGET_1 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID);

CREATE TABLE SBI_WIDGET_GALLERY (
  UUID CHAR(36) NOT NULL, -- primary key
  NAME VARCHAR(200) NOT NULL,
  DESCRIPTION VARCHAR(500) NULL,
  TYPE VARCHAR(45) NULL, -- HTML/CUSTOM CHART/PYTHON/R
  PREVIEW_IMAGE BLOB NULL, -- binary of preview file
  TEMPLATE BLOB NULL, -- text with template as a JSON
  AUTHOR VARCHAR(100) NULL,
  USAGE_COUNTER INT NULL, -- counter to see how many times the widgets was used
  USER_IN              VARCHAR2(100) NOT NULL,
  USER_UP              VARCHAR2(100),
  USER_DE              VARCHAR2(100),
  TIME_IN              TIMESTAMP NOT NULL,
  TIME_UP              TIMESTAMP DEFAULT NULL,
  TIME_DE              TIMESTAMP DEFAULT NULL,
  SBI_VERSION_IN       VARCHAR2(10),
  SBI_VERSION_UP       VARCHAR2(10),
  SBI_VERSION_DE       VARCHAR2(10),
  ORGANIZATION         VARCHAR2(20),		
  OUTPUT_TYPE         VARCHAR2(100),
  LABEL 			  VARCHAR(200) NOT NULL,
 CONSTRAINT  XAK1SBI_WIDGET_GALLERY UNIQUE (NAME, ORGANIZATION),
  PRIMARY KEY (UUID, ORGANIZATION)
);

CREATE TABLE SBI_WIDGET_GALLERY_TAGS (
  WIDGET_ID CHAR(36) NOT NULL, -- widget id reference
  TAG VARCHAR(50) NOT NULL, -- tag name
 USER_IN              VARCHAR2(100) NOT NULL,
		USER_UP              VARCHAR2(100),
		USER_DE              VARCHAR2(100),
		TIME_IN              TIMESTAMP NOT NULL,
		TIME_UP              TIMESTAMP DEFAULT NULL,
		TIME_DE              TIMESTAMP DEFAULT NULL,
		SBI_VERSION_IN       VARCHAR2(10),
		SBI_VERSION_UP       VARCHAR2(10),
		SBI_VERSION_DE       VARCHAR2(10),
		ORGANIZATION         VARCHAR2(20),
  PRIMARY KEY  (WIDGET_ID,TAG, ORGANIZATION),
  CONSTRAINT FK_SBI_WIDGET_GALLERY_TAGS_1 FOREIGN KEY (WIDGET_ID, ORGANIZATION) REFERENCES SBI_WIDGET_GALLERY (UUID, ORGANIZATION) ON DELETE CASCADE
);

CREATE TABLE SBI_ORGANIZATION_THEME (
	UUID 				 VARCHAR(36) NOT NULL,
	ORGANIZATION_ID 	 INTEGER NOT NULL,
	THEME_NAME 			 VARCHAR(255) NOT NULL,
	CONFIG 				 CLOB NULL,
	ACTIVE 				 SMALLINT DEFAULT 0,
	USER_IN              VARCHAR2(100) NOT NULL,
	USER_UP              VARCHAR2(100),
	USER_DE              VARCHAR2(100),
	TIME_IN              TIMESTAMP NOT NULL,
	TIME_UP              TIMESTAMP DEFAULT NULL,
	TIME_DE              TIMESTAMP DEFAULT NULL,
	SBI_VERSION_IN       VARCHAR2(10),
	SBI_VERSION_UP       VARCHAR2(10),
	SBI_VERSION_DE       VARCHAR2(10),
	ORGANIZATION         VARCHAR2(20),
	PRIMARY KEY (UUID, ORGANIZATION),
	CONSTRAINT FK_ORGANIZATION_1 FOREIGN KEY (ORGANIZATION_ID) REFERENCES SBI_ORGANIZATIONS(ID)
);


-- CREATE INDEXES SECTION

CREATE INDEX FK_SBI_AUDIT_1 ON SBI_AUDIT (DOC_REF);
CREATE INDEX FK_SBI_AUDIT_2 ON SBI_AUDIT (ENGINE_REF);
CREATE INDEX FK_SBI_AUDIT_3 ON SBI_AUDIT (SUBOBJ_REF);
CREATE INDEX XIF3SBI_CHECKS ON SBI_CHECKS (VALUE_TYPE_ID);
CREATE INDEX FK_SBI_DATA_SOURCE_1 ON SBI_DATA_SOURCE (DIALECT_ID);
CREATE INDEX FK_SBI_DISTRIBUTION_LISTS_OBJE ON SBI_DIST_LIST_OBJECTS (DOC_ID);
CREATE INDEX FK_SBI_DISTRIBUTION_LISTS_DLID ON SBI_DIST_LIST_OBJECTS (DL_ID);
CREATE INDEX FK_SBI_ENGINES_1 ON SBI_ENGINES (BIOBJ_TYPE);
CREATE INDEX FK_SBI_ENGINES_2 ON SBI_ENGINES (ENGINE_TYPE);
CREATE INDEX FK_SBI_EVENTS_ROLES_1 ON SBI_EVENTS_ROLES (ROLE_ID);
CREATE INDEX XIF1SBI_EXT_ROLES ON SBI_EXT_ROLES (ROLE_TYPE_ID);
CREATE INDEX XIF1SBI_FUNC_ROLE ON SBI_FUNC_ROLE (ROLE_ID);
CREATE INDEX XIF2SBI_FUNC_ROLE ON SBI_FUNC_ROLE (FUNCT_ID);
CREATE INDEX XIF4SBI_FUNC_ROLE ON SBI_FUNC_ROLE (STATE_ID);
CREATE INDEX XIF1SBI_FUNCTIONS ON SBI_FUNCTIONS (FUNCT_TYPE_ID);
CREATE INDEX XIF2SBI_FUNCTIONS ON SBI_FUNCTIONS (PARENT_FUNCT_ID);
CREATE INDEX FK_GEO_MAP_FEATURES2 ON SBI_GEO_MAP_FEATURES (FEATURE_ID);
CREATE INDEX XIF3SBI_LOV ON SBI_LOV (INPUT_TYPE_ID);
CREATE INDEX XIF1SBI_OBJ_FUNC ON SBI_OBJ_FUNC (BIOBJ_ID);
CREATE INDEX XIF2SBI_OBJ_FUNC ON SBI_OBJ_FUNC (FUNCT_ID);
CREATE INDEX XIF1SBI_OBJ_PAR ON SBI_OBJ_PAR (PAR_ID);
CREATE INDEX XIF2SBI_OBJ_PAR ON SBI_OBJ_PAR (BIOBJ_ID);
CREATE INDEX FK_SBI_OBJ_PARUSE_2 ON SBI_OBJ_PARUSE (USE_ID);
CREATE INDEX FK_SBI_OBJ_PARUSE_3 ON SBI_OBJ_PARUSE (OBJ_PAR_FATHER_ID);
CREATE INDEX XIF3SBI_OBJ_STATE ON SBI_OBJ_STATE (BIOBJ_ID);
CREATE INDEX XIF4SBI_OBJ_STATE ON SBI_OBJ_STATE (STATE_ID);
CREATE INDEX FK_SBI_OBJECT_NOTES_1 ON SBI_OBJECT_NOTES (BIN_ID);
CREATE INDEX FK_SBI_OBJECT_NOTES_2 ON SBI_OBJECT_NOTES (BIOBJ_ID);
CREATE INDEX FK_SBI_OBJECT_TEMPLATES_1 ON SBI_OBJECT_TEMPLATES (BIN_ID);
CREATE INDEX FK_SBI_OBJECT_TEMPLATES_2 ON SBI_OBJECT_TEMPLATES (BIOBJ_ID);
CREATE INDEX XIF2SBI_OBJECTS ON SBI_OBJECTS (STATE_ID);
CREATE INDEX XIF4SBI_OBJECTS ON SBI_OBJECTS (BIOBJ_TYPE_ID);
CREATE INDEX XIF5SBI_OBJECTS ON SBI_OBJECTS (EXEC_MODE_ID);
CREATE INDEX XIF6SBI_OBJECTS ON SBI_OBJECTS (STATE_CONS_ID);
CREATE INDEX FK_SBI_OBJECTS_RATING_1 ON SBI_OBJECTS_RATING (OBJ_ID);
CREATE INDEX XIF1SBI_PARAMETERS ON SBI_PARAMETERS (PAR_TYPE_ID);
CREATE INDEX XIF1SBI_PARUSE ON SBI_PARUSE (PAR_ID);
CREATE INDEX XIF2SBI_PARUSE ON SBI_PARUSE (LOV_ID);
CREATE INDEX XIF3SBI_PARUSE ON SBI_PARUSE (DEFAULT_LOV_ID);
CREATE INDEX XIF1SBI_PARUSE_CK ON SBI_PARUSE_CK (USE_ID);
CREATE INDEX XIF2SBI_PARUSE_CK ON SBI_PARUSE_CK (CHECK_ID);
CREATE INDEX XIF2SBI_PARUSE_DET ON SBI_PARUSE_DET (EXT_ROLE_ID);
CREATE INDEX XIF3SBI_PARUSE_DET ON SBI_PARUSE_DET (USE_ID);
CREATE INDEX FK_SBI_REMEMBER_ME_1 ON SBI_REMEMBER_ME (BIOBJ_ID);
CREATE INDEX FK_SBI_REMEMBER_ME_2 ON SBI_REMEMBER_ME (SUBOBJ_ID);
CREATE INDEX FK_SBI_ROLE_TYPE_USER_FUNCTION ON SBI_ROLE_TYPE_USER_FUNC (USER_FUNCT_ID);
CREATE INDEX FK_SBI_SNAPSHOTS_1 ON SBI_SNAPSHOTS (BIN_ID);
CREATE INDEX FK_SBI_SNAPSHOTS_2 ON SBI_SNAPSHOTS (BIOBJ_ID);
CREATE INDEX FK_SBI_SUBOBJECTS_1 ON SBI_SUBOBJECTS (BIN_ID);
CREATE INDEX FK_SBI_SUBOBJECTS_2 ON SBI_SUBOBJECTS (BIOBJ_ID);
CREATE INDEX FK_SBI_SUBREPORTS_2 ON SBI_SUBREPORTS (SUB_RPT_ID);
CREATE INDEX FK_SBI_VIEWPOINTS_1 ON SBI_VIEWPOINTS (BIOBJ_ID);
CREATE UNIQUE INDEX XAK1SBI_OBJ_METACONTENTS ON SBI_OBJ_METACONTENTS(OBJMETA_ID,BIOBJ_ID,SUBOBJ_ID);
CREATE UNIQUE INDEX XAK1SBI_USER ON SBI_USER(USER_ID);
CREATE INDEX XIF3_SBI_SBI_UDP ON SBI_UDP(TYPE_ID  ASC);
CREATE INDEX XIF2SBI_SBI_UDP ON SBI_UDP(FAMILY_ID ASC);
CREATE INDEX XIF2SBI_SBI_UDP_VALUE ON SBI_UDP_VALUE(UDP_ID ASC);

CREATE INDEX XAK1SBI_PARVIEW ON SBI_OBJ_PARVIEW ( OBJ_PAR_ID ASC, OBJ_PAR_FATHER_ID ASC);
CREATE UNIQUE INDEX XAK1SBI_CONFIG ON SBI_CONFIG(LABEL);
CREATE INDEX XAX1_SBI_AUTHORIZATIONS_ROLES ON SBI_AUTHORIZATIONS_ROLES (AUTHORIZATION_ID);
-- CREATE FOREIGN KEYS SECTION

CREATE INDEX IDX_SBI_ORG_PRODUCT_TYPE 		ON SBI_ORGANIZATION_PRODUCT_TYPE (ORGANIZATION_ID);
CREATE INDEX IDX_SBI_GL_WORD_01 			ON SBI_GL_WORD (STATE);
CREATE INDEX IDX_SBI_GL_WORD_02 			ON SBI_GL_WORD (CATEGORY);
CREATE INDEX IDX_SBI_GL_DOCWLIST 			ON SBI_GL_DOCWLIST (WORD_ID ASC);
CREATE INDEX IDX_SBI_GL_DATASETWLIST_01		ON SBI_GL_DATASETWLIST (DS_ID);
CREATE INDEX IDX_SBI_GL_DATASETWLIST_02		ON SBI_GL_DATASETWLIST (ORGANIZATION);
CREATE INDEX IDX_SBI_GL_BNESS_CLS_WLIST 	ON SBI_GL_BNESS_CLS_WLIST (WORD_ID);
CREATE INDEX IDX_SBI_ROLES_LAYERS 			ON SBI_ROLES_LAYERS (ID_ROLE);

ALTER TABLE SBI_OBJECT_NOTES ADD CONSTRAINT SBI_OBJECT_NOTES_1 FOREIGN KEY (BIN_ID) REFERENCES SBI_BINARY_CONTENTS (BIN_ID);
ALTER TABLE SBI_OBJECT_NOTES ADD CONSTRAINT SBI_OBJECT_NOTES_2 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID);

ALTER TABLE SBI_OBJECT_TEMPLATES ADD CONSTRAINT SBI_OBJECT_TEMPLATES_1 FOREIGN KEY (BIN_ID) REFERENCES SBI_BINARY_CONTENTS (BIN_ID);
ALTER TABLE SBI_OBJECT_TEMPLATES ADD CONSTRAINT SBI_OBJECT_TEMPLATES_2 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID);

ALTER TABLE SBI_SNAPSHOTS ADD CONSTRAINT SBI_SNAPSHOTS_1 FOREIGN KEY (BIN_ID) REFERENCES SBI_BINARY_CONTENTS (BIN_ID);
ALTER TABLE SBI_SNAPSHOTS ADD CONSTRAINT SBI_SNAPSHOTS_2 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID);

ALTER TABLE SBI_SUBOBJECTS ADD CONSTRAINT SBI_SUBOBJECTS_1 FOREIGN KEY (BIN_ID) REFERENCES SBI_BINARY_CONTENTS (BIN_ID);
ALTER TABLE SBI_SUBOBJECTS ADD CONSTRAINT SBI_SUBOBJECTS_2 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID);

ALTER TABLE SBI_PARUSE_CK ADD CONSTRAINT SBI_PARUSE_CK_1 FOREIGN KEY (CHECK_ID) REFERENCES SBI_CHECKS (CHECK_ID);
ALTER TABLE SBI_PARUSE_CK ADD CONSTRAINT SBI_PARUSE_CK_2 FOREIGN KEY (USE_ID) REFERENCES SBI_PARUSE (USE_ID);


ALTER TABLE SBI_ENGINES ADD CONSTRAINT SBI_ENGINES_2 FOREIGN KEY (BIOBJ_TYPE) REFERENCES SBI_DOMAINS (VALUE_ID);
ALTER TABLE SBI_ENGINES ADD CONSTRAINT SBI_ENGINES_3 FOREIGN KEY (ENGINE_TYPE) REFERENCES SBI_DOMAINS (VALUE_ID);

ALTER TABLE SBI_DIST_LIST_USER ADD CONSTRAINT SBI_DIST_LIST_USER_1 FOREIGN KEY (LIST_ID) REFERENCES SBI_DIST_LIST (DL_ID)  ON DELETE CASCADE;

ALTER TABLE SBI_DIST_LIST_OBJECTS ADD CONSTRAINT SBI_DIST_LIST_OBJECTS_1 FOREIGN KEY (DL_ID) REFERENCES SBI_DIST_LIST (DL_ID)  ON DELETE CASCADE;
ALTER TABLE SBI_DIST_LIST_OBJECTS ADD CONSTRAINT SBI_DIST_LIST_OBJECTS_2 FOREIGN KEY (DOC_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID)  ON DELETE CASCADE;

ALTER TABLE SBI_CHECKS ADD CONSTRAINT SBI_CHECKS_1 FOREIGN KEY (VALUE_TYPE_ID) REFERENCES SBI_DOMAINS (VALUE_ID);

ALTER TABLE SBI_DATA_SOURCE ADD CONSTRAINT SBI_DATA_SOURCE_1 FOREIGN KEY (DIALECT_ID) REFERENCES SBI_DOMAINS (VALUE_ID);

ALTER TABLE SBI_EXT_ROLES ADD CONSTRAINT SBI_EXT_ROLES_1 FOREIGN KEY (ROLE_TYPE_ID) REFERENCES SBI_DOMAINS (VALUE_ID);

ALTER TABLE SBI_FUNC_ROLE ADD CONSTRAINT SBI_FUNC_ROLE_1 FOREIGN KEY (STATE_ID) REFERENCES SBI_DOMAINS (VALUE_ID);
ALTER TABLE SBI_FUNC_ROLE ADD CONSTRAINT SBI_FUNC_ROLE_2 FOREIGN KEY (FUNCT_ID) REFERENCES SBI_FUNCTIONS (FUNCT_ID);
ALTER TABLE SBI_FUNC_ROLE ADD CONSTRAINT SBI_FUNC_ROLE_3 FOREIGN KEY (ROLE_ID) REFERENCES SBI_EXT_ROLES (EXT_ROLE_ID);

ALTER TABLE SBI_FUNCTIONS ADD CONSTRAINT SBI_FUNCTIONS_1 FOREIGN KEY (FUNCT_TYPE_ID) REFERENCES SBI_DOMAINS (VALUE_ID);
ALTER TABLE SBI_FUNCTIONS ADD CONSTRAINT SBI_FUNCTIONS_2 FOREIGN KEY (PARENT_FUNCT_ID) REFERENCES SBI_FUNCTIONS (FUNCT_ID);

ALTER TABLE SBI_LOV ADD CONSTRAINT SBI_LOV_1 FOREIGN KEY (INPUT_TYPE_ID) REFERENCES SBI_DOMAINS (VALUE_ID);

ALTER TABLE SBI_OBJ_STATE ADD CONSTRAINT SBI_OBJ_STATE_1 FOREIGN KEY (STATE_ID) REFERENCES SBI_DOMAINS (VALUE_ID);
ALTER TABLE SBI_OBJ_STATE ADD CONSTRAINT SBI_OBJ_STATE_2 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID);

ALTER TABLE SBI_OBJECTS ADD CONSTRAINT SBI_OBJECTS_1 FOREIGN KEY (DATA_SOURCE_ID) REFERENCES SBI_DATA_SOURCE (DS_ID);
ALTER TABLE SBI_OBJECTS ADD CONSTRAINT SBI_OBJECTS_2 FOREIGN KEY (STATE_CONS_ID) REFERENCES SBI_DOMAINS (VALUE_ID);
ALTER TABLE SBI_OBJECTS ADD CONSTRAINT SBI_OBJECTS_3 FOREIGN KEY (STATE_ID) REFERENCES SBI_DOMAINS (VALUE_ID);
ALTER TABLE SBI_OBJECTS ADD CONSTRAINT SBI_OBJECTS_4 FOREIGN KEY (BIOBJ_TYPE_ID) REFERENCES SBI_DOMAINS (VALUE_ID);
ALTER TABLE SBI_OBJECTS ADD CONSTRAINT SBI_OBJECTS_5 FOREIGN KEY (EXEC_MODE_ID) REFERENCES SBI_DOMAINS (VALUE_ID);
ALTER TABLE SBI_OBJECTS ADD CONSTRAINT SBI_OBJECTS_6 FOREIGN KEY (ENGINE_ID) REFERENCES SBI_ENGINES (ENGINE_ID);

ALTER TABLE SBI_PARAMETERS ADD CONSTRAINT SBI_PARAMETERS_1 FOREIGN KEY (PAR_TYPE_ID) REFERENCES SBI_DOMAINS (VALUE_ID);

ALTER TABLE SBI_ROLE_TYPE_USER_FUNC ADD CONSTRAINT SBI_ROLE_TYPE_USER_FUNC_1 FOREIGN KEY (ROLE_TYPE_ID) REFERENCES SBI_DOMAINS (VALUE_ID);
ALTER TABLE SBI_ROLE_TYPE_USER_FUNC ADD CONSTRAINT SBI_ROLE_TYPE_USER_FUNC_2 FOREIGN KEY (USER_FUNCT_ID) REFERENCES SBI_USER_FUNC (USER_FUNCT_ID);

ALTER TABLE SBI_AUDIT ADD CONSTRAINT SBI_AUDIT_1 FOREIGN KEY (ENGINE_REF) REFERENCES SBI_ENGINES (ENGINE_ID)  ON DELETE SET NULL;
ALTER TABLE SBI_AUDIT ADD CONSTRAINT SBI_AUDIT_2 FOREIGN KEY (DOC_REF) REFERENCES SBI_OBJECTS (BIOBJ_ID)  ON DELETE SET NULL;
ALTER TABLE SBI_AUDIT ADD CONSTRAINT SBI_AUDIT_3 FOREIGN KEY (SUBOBJ_REF) REFERENCES SBI_SUBOBJECTS (SUBOBJ_ID)  ON DELETE SET NULL;

ALTER TABLE SBI_EVENTS_ROLES ADD CONSTRAINT SBI_EVENTS_ROLES_1 FOREIGN KEY (EVENT_ID) REFERENCES SBI_EVENTS_LOG (ID);
ALTER TABLE SBI_EVENTS_ROLES ADD CONSTRAINT SBI_EVENTS_ROLES_2 FOREIGN KEY (ROLE_ID) REFERENCES SBI_EXT_ROLES (EXT_ROLE_ID);


ALTER TABLE SBI_PARUSE_DET ADD CONSTRAINT SBI_PARUSE_DET_1 FOREIGN KEY (EXT_ROLE_ID) REFERENCES SBI_EXT_ROLES (EXT_ROLE_ID);
ALTER TABLE SBI_PARUSE_DET ADD CONSTRAINT SBI_PARUSE_DET_2 FOREIGN KEY (USE_ID) REFERENCES SBI_PARUSE (USE_ID);


ALTER TABLE SBI_OBJ_FUNC ADD CONSTRAINT SBI_OBJ_FUNC_1 FOREIGN KEY (FUNCT_ID) REFERENCES SBI_FUNCTIONS (FUNCT_ID);
ALTER TABLE SBI_OBJ_FUNC ADD CONSTRAINT SBI_OBJ_FUNC_2 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID);

ALTER TABLE SBI_GEO_MAPS ADD CONSTRAINT SBI_GEO_MAPS_1 FOREIGN KEY (BIN_ID) REFERENCES SBI_BINARY_CONTENTS (BIN_ID);

ALTER TABLE SBI_GEO_MAP_FEATURES ADD CONSTRAINT SBI_GEO_MAP_FEATURES_1 FOREIGN KEY (FEATURE_ID) REFERENCES SBI_GEO_FEATURES (FEATURE_ID);
ALTER TABLE SBI_GEO_MAP_FEATURES ADD CONSTRAINT SBI_GEO_MAP_FEATURES_2 FOREIGN KEY (MAP_ID) REFERENCES SBI_GEO_MAPS (MAP_ID);

ALTER TABLE SBI_PARUSE ADD CONSTRAINT SBI_PARUSE_1 FOREIGN KEY (LOV_ID) REFERENCES SBI_LOV (LOV_ID);
ALTER TABLE SBI_PARUSE ADD CONSTRAINT SBI_PARUSE_2 FOREIGN KEY (PAR_ID) REFERENCES SBI_PARAMETERS (PAR_ID);
ALTER TABLE SBI_PARUSE ADD CONSTRAINT SBI_PARUSE_3 FOREIGN KEY (DEFAULT_LOV_ID) REFERENCES SBI_LOV (LOV_ID);

ALTER TABLE SBI_OBJ_PARUSE ADD CONSTRAINT SBI_OBJ_PARUSE_1 FOREIGN KEY (OBJ_PAR_ID) REFERENCES SBI_OBJ_PAR (OBJ_PAR_ID);
ALTER TABLE SBI_OBJ_PARUSE ADD CONSTRAINT SBI_OBJ_PARUSE_2 FOREIGN KEY (OBJ_PAR_FATHER_ID) REFERENCES SBI_OBJ_PAR (OBJ_PAR_ID);
ALTER TABLE SBI_OBJ_PARUSE ADD CONSTRAINT SBI_OBJ_PARUSE_3 FOREIGN KEY (USE_ID) REFERENCES SBI_PARUSE (USE_ID);

ALTER TABLE SBI_OBJ_PAR ADD CONSTRAINT SBI_OBJ_PAR_1 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID);
ALTER TABLE SBI_OBJ_PAR ADD CONSTRAINT SBI_OBJ_PAR_2 FOREIGN KEY (PAR_ID) REFERENCES SBI_PARAMETERS (PAR_ID);

ALTER TABLE SBI_OBJECTS_RATING ADD CONSTRAINT SBI_OBJECTS_RATING_1 FOREIGN KEY (OBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID)  ON DELETE CASCADE;

ALTER TABLE SBI_REMEMBER_ME ADD CONSTRAINT SBI_REMEMBER_ME_1 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID)  ON DELETE CASCADE;
ALTER TABLE SBI_REMEMBER_ME ADD CONSTRAINT SBI_REMEMBER_ME_2 FOREIGN KEY (SUBOBJ_ID) REFERENCES SBI_SUBOBJECTS (SUBOBJ_ID)  ON DELETE CASCADE;

ALTER TABLE SBI_SUBREPORTS ADD CONSTRAINT SBI_SUBREPORTS_1 FOREIGN KEY (MASTER_RPT_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID);
ALTER TABLE SBI_SUBREPORTS ADD CONSTRAINT SBI_SUBREPORTS_2 FOREIGN KEY (SUB_RPT_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID);

ALTER TABLE SBI_VIEWPOINTS ADD CONSTRAINT SBI_VIEWPOINTS_1 FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID);

ALTER TABLE SBI_MENU_ROLE ADD CONSTRAINT SBI_MENU_ROLE_1 FOREIGN KEY (MENU_ID) REFERENCES SBI_MENU (MENU_ID) ON DELETE CASCADE;
ALTER TABLE SBI_MENU_ROLE ADD CONSTRAINT SBI_MENU_ROLE_2 FOREIGN KEY (EXT_ROLE_ID) REFERENCES SBI_EXT_ROLES (EXT_ROLE_ID) ON DELETE CASCADE;
ALTER TABLE SBI_UDP ADD CONSTRAINT FK_SBI_SBI_UDP_1 FOREIGN KEY ( TYPE_ID ) REFERENCES SBI_DOMAINS ( VALUE_ID );
ALTER TABLE SBI_UDP ADD CONSTRAINT FK_SBI_SBI_UDP_2 FOREIGN KEY ( FAMILY_ID ) REFERENCES SBI_DOMAINS ( VALUE_ID );
ALTER TABLE SBI_UDP_VALUE ADD CONSTRAINT FK_SBI_UDP_VALUE_1 FOREIGN KEY ( UDP_ID ) REFERENCES SBI_UDP ( UDP_ID );

ALTER TABLE SBI_EXPORTERS ADD CONSTRAINT SBI_EXPORTERS_12 FOREIGN KEY (ENGINE_ID) REFERENCES SBI_ENGINES (ENGINE_ID);
ALTER TABLE SBI_EXPORTERS ADD CONSTRAINT SBI_EXPORTERS_13 FOREIGN KEY (DOMAIN_ID) REFERENCES SBI_DOMAINS (VALUE_ID);
ALTER TABLE SBI_OBJ_METADATA ADD CONSTRAINT FK_SBI_OBJ_METADATA_1 FOREIGN KEY ( DATA_TYPE_ID ) REFERENCES SBI_DOMAINS(VALUE_ID);
ALTER TABLE SBI_OBJ_METACONTENTS ADD CONSTRAINT FK_SBI_OBJ_METACONTENTS_1 FOREIGN KEY  ( OBJMETA_ID ) REFERENCES SBI_OBJ_METADATA (  OBJ_META_ID );
ALTER TABLE SBI_OBJ_METACONTENTS ADD CONSTRAINT FK_SBI_OBJ_METACONTENTS_2 FOREIGN KEY  ( BIOBJ_ID )   REFERENCES SBI_OBJECTS (  BIOBJ_ID );
ALTER TABLE SBI_OBJ_METACONTENTS ADD CONSTRAINT FK_SBI_OBJ_METACONTENTS_3 FOREIGN KEY  ( SUBOBJ_ID )  REFERENCES SBI_SUBOBJECTS (  SUBOBJ_ID );
ALTER TABLE SBI_OBJ_METACONTENTS ADD CONSTRAINT FK_SBI_OBJ_METACONTENTS_4 FOREIGN KEY  ( BIN_ID )     REFERENCES SBI_BINARY_CONTENTS(BIN_ID);
ALTER TABLE SBI_CONFIG ADD CONSTRAINT FK_SBI_CONFIG_1 FOREIGN KEY ( VALUE_TYPE_ID ) REFERENCES SBI_DOMAINS ( VALUE_ID );
ALTER TABLE SBI_USER_ATTRIBUTES ADD CONSTRAINT FK_SBI_USER_ATTRIBUTES_1 FOREIGN KEY (ID) REFERENCES SBI_USER (ID);
ALTER TABLE SBI_EXT_USER_ROLES ADD CONSTRAINT FK_SBI_EXT_USER_ROLES_1 FOREIGN KEY (ID) REFERENCES SBI_USER (ID);
ALTER TABLE SBI_USER_ATTRIBUTES ADD CONSTRAINT FK_SBI_USER_ATTRIBUTES_2 FOREIGN KEY (ATTRIBUTE_ID) REFERENCES SBI_ATTRIBUTE (ATTRIBUTE_ID);
ALTER TABLE SBI_EXT_USER_ROLES ADD CONSTRAINT FK_SBI_EXT_USER_ROLES_2 FOREIGN KEY (EXT_ROLE_ID) REFERENCES SBI_EXT_ROLES (EXT_ROLE_ID);

ALTER TABLE SBI_OBJ_PARVIEW ADD CONSTRAINT FK_SBI_OBJ_PARVIEW_1 FOREIGN KEY ( OBJ_PAR_ID ) REFERENCES SBI_OBJ_PAR ( OBJ_PAR_ID );
ALTER TABLE SBI_OBJ_PARVIEW ADD CONSTRAINT FK_SBI_OBJ_PARVIEW_2 FOREIGN KEY ( OBJ_PAR_FATHER_ID ) REFERENCES SBI_OBJ_PAR ( OBJ_PAR_ID );

ALTER TABLE SBI_I18N_MESSAGES ADD CONSTRAINT FK_SBI_I18N_MESSAGES FOREIGN KEY (LANGUAGE_CD) REFERENCES SBI_DOMAINS(VALUE_ID);
ALTER TABLE SBI_I18N_MESSAGES ADD CONSTRAINT SBI_I18N_MESSAGES_UNIQUE UNIQUE (LANGUAGE_CD, LABEL, ORGANIZATION);

ALTER TABLE SBI_META_MODELS_VERSIONS ADD CONSTRAINT FK_SBI_META_MODELS_VERSIONS_1 FOREIGN KEY ( MODEL_ID ) REFERENCES SBI_META_MODELS( ID ) ON DELETE CASCADE;

ALTER TABLE SBI_ARTIFACTS_VERSIONS ADD CONSTRAINT FK_SBI_ARTIFACTS_VERSIONS_1 FOREIGN KEY ( ARTIFACT_ID ) REFERENCES SBI_ARTIFACTS( ID ) ON DELETE CASCADE;

--ALTER TABLE SBI_META_MODELS ADD CONSTRAINT FK_SBIDATA_SOURCE 	FOREIGN KEY ( DATA_SOURCE_ID ) REFERENCES SBI_DATA_SOURCE( DS_ID );
ALTER TABLE SBI_DATA_SET 	ADD CONSTRAINT FK_DATA_SET_CATEGORY FOREIGN KEY (CATEGORY_ID) 	   REFERENCES SBI_DOMAINS (VALUE_ID);
ALTER TABLE SBI_DATA_SET    ADD CONSTRAINT FK_SBI_DOMAINS_2 FOREIGN KEY ( SCOPE_ID ) REFERENCES SBI_DOMAINS( VALUE_ID ) ON DELETE CASCADE;
ALTER TABLE SBI_OBJ_DATA_SET ADD CONSTRAINT FK_SBI_OBJ_DATA_SET FOREIGN KEY (BIOBJ_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID);


ALTER TABLE SBI_META_MODELS ADD CONSTRAINT FK_META_MODELS_CATEGORY FOREIGN KEY (CATEGORY_ID) REFERENCES SBI_DOMAINS (VALUE_ID);
ALTER TABLE SBI_METAMODEL_VIEWPOINTS ADD CONSTRAINT FK_SBI_METAMODEL_VIEWPOINTS_1 FOREIGN KEY (METAMODEL_ID) REFERENCES SBI_META_MODELS (ID);

ALTER TABLE SBI_AUTHORIZATIONS_ROLES ADD CONSTRAINT FK_ROLE1 FOREIGN KEY (ROLE_ID) REFERENCES SBI_EXT_ROLES (EXT_ROLE_ID);
ALTER TABLE SBI_AUTHORIZATIONS_ROLES ADD CONSTRAINT FK_AUTHORIZATION_1 FOREIGN KEY (AUTHORIZATION_ID) REFERENCES SBI_AUTHORIZATIONS (ID);

ALTER TABLE SBI_COMMUNITY_USERS ADD CONSTRAINT FK_COMMUNITY FOREIGN KEY (COMMUNITY_ID) REFERENCES SBI_COMMUNITY (COMMUNITY_ID) ON DELETE CASCADE;

ALTER TABLE SBI_ORGANIZATION_DATASOURCE ADD CONSTRAINT FK_DATASOURCE_2 FOREIGN KEY (DATASOURCE_ID) REFERENCES SBI_DATA_SOURCE (DS_ID);
ALTER TABLE SBI_ORGANIZATION_DATASOURCE ADD   CONSTRAINT FK_ORGANIZATION_2 FOREIGN KEY (ORGANIZATION_ID) REFERENCES SBI_ORGANIZATIONS (ID);

ALTER TABLE SBI_USER_FUNC 					ADD CONSTRAINT FK_PRODUCT_TYPE 					FOREIGN KEY (PRODUCT_TYPE_ID) 		REFERENCES SBI_PRODUCT_TYPE (PRODUCT_TYPE_ID);
ALTER TABLE SBI_ORGANIZATION_PRODUCT_TYPE 	ADD CONSTRAINT FK_PRODUCT_TYPE_1 				FOREIGN KEY (PRODUCT_TYPE_ID) 		REFERENCES SBI_PRODUCT_TYPE (PRODUCT_TYPE_ID);
ALTER TABLE SBI_ORGANIZATION_PRODUCT_TYPE 	ADD CONSTRAINT FK_ORGANIZATION_3 				FOREIGN KEY (ORGANIZATION_ID) 		REFERENCES SBI_ORGANIZATIONS (ID);
ALTER TABLE SBI_AUTHORIZATIONS 				ADD CONSTRAINT FK2_PRODUCT_TYPE 				FOREIGN KEY (PRODUCT_TYPE_ID)		REFERENCES SBI_PRODUCT_TYPE (PRODUCT_TYPE_ID);
ALTER TABLE SBI_GL_WORD 					ADD CONSTRAINT FK_01_SBI_GL_WORD				FOREIGN KEY (CATEGORY) 				REFERENCES SBI_DOMAINS (VALUE_ID);
ALTER TABLE SBI_GL_WORD 					ADD CONSTRAINT FK_02_SBI_GL_WORD 				FOREIGN KEY (STATE) 				REFERENCES SBI_DOMAINS (VALUE_ID);
ALTER TABLE SBI_GL_DOCWLIST 				ADD CONSTRAINT FK_01_SBI_GL_DOCWLIST 			FOREIGN KEY (WORD_ID) 				REFERENCES SBI_GL_WORD (WORD_ID);
ALTER TABLE SBI_GL_DOCWLIST 				ADD CONSTRAINT FK_02_SBI_GL_DOCWLIST 			FOREIGN KEY (BIOBJ_ID) 				REFERENCES SBI_OBJECTS (BIOBJ_ID);
ALTER TABLE SBI_GL_DATASETWLIST 			ADD CONSTRAINT FK_02_SBI_GL_DATASETWLIST 		FOREIGN KEY (WORD_ID) 				REFERENCES SBI_GL_WORD (WORD_ID);
ALTER TABLE SBI_GL_BNESS_CLS_WLIST          ADD CONSTRAINT FK_01_SBI_GL_BNESS_CLS_WLIST     FOREIGN KEY (BC_ID)                 REFERENCES SBI_META_BC (BC_ID);
ALTER TABLE SBI_GL_BNESS_CLS_WLIST 			ADD CONSTRAINT FK_02_SBI_GL_BNESS_CLS_WLIST 	FOREIGN KEY (WORD_ID) 				REFERENCES SBI_GL_WORD (WORD_ID);
ALTER TABLE SBI_GL_TABLE_WLIST 				ADD CONSTRAINT FK_01_SBI_GL_TABLE_WLIST         FOREIGN KEY (TABLE_ID)              REFERENCES SBI_META_TABLE (TABLE_ID);
ALTER TABLE SBI_GL_TABLE_WLIST 				ADD CONSTRAINT FK_02_SBI_GL_TABLE_WLIST 		FOREIGN KEY (WORD_ID) 				REFERENCES SBI_GL_WORD (WORD_ID);
ALTER TABLE SBI_GL_WORD_ATTR 				ADD CONSTRAINT FK_01_GL_WORD_ATTR				FOREIGN KEY (WORD_ID) 				REFERENCES SBI_GL_WORD (WORD_ID);
ALTER TABLE SBI_GL_WORD_ATTR 				ADD CONSTRAINT FK_02_GL_WORD_ATTR				FOREIGN KEY (ATTRIBUTE_ID) 			REFERENCES SBI_GL_ATTRIBUTES (ATTRIBUTE_ID);
ALTER TABLE SBI_GL_REFERENCES 				ADD CONSTRAINT FK_01_GL_REFERENCES				FOREIGN KEY (WORD_ID) 				REFERENCES SBI_GL_WORD (WORD_ID);
ALTER TABLE SBI_GL_REFERENCES 				ADD CONSTRAINT FK_02_GL_REFERENCES				FOREIGN KEY (REF_WORD_ID) 			REFERENCES SBI_GL_WORD (WORD_ID);
ALTER TABLE SBI_GL_WLIST 					ADD CONSTRAINT FK_01_GL_WLIST					FOREIGN KEY (WORD_ID) 				REFERENCES SBI_GL_WORD (WORD_ID);
ALTER TABLE SBI_GL_WLIST 					ADD CONSTRAINT FK_02_GL_WLIST					FOREIGN KEY (CONTENT_ID) 			REFERENCES SBI_GL_CONTENTS (CONTENT_ID);
ALTER TABLE SBI_GL_CONTENTS 				ADD CONSTRAINT FK_01_GL_CONTENTS				FOREIGN KEY (GLOSSARY_ID) 			REFERENCES SBI_GL_GLOSSARY (GLOSSARY_ID);
ALTER TABLE SBI_GL_CONTENTS 				ADD CONSTRAINT FK_02_GL_CONTENTS				FOREIGN KEY (PARENT_ID) 			REFERENCES SBI_GL_CONTENTS (CONTENT_ID);
ALTER TABLE SBI_PRODUCT_TYPE_ENGINE 		ADD CONSTRAINT FK_PRODUCT_TYPE_2 				FOREIGN KEY (PRODUCT_TYPE_ID) 		REFERENCES SBI_PRODUCT_TYPE (PRODUCT_TYPE_ID);
ALTER TABLE SBI_PRODUCT_TYPE_ENGINE 		ADD CONSTRAINT FK_ENGINE_2 						FOREIGN KEY (ENGINE_ID)				REFERENCES SBI_ENGINES (ENGINE_ID);
ALTER TABLE SBI_OUTPUT_PARAMETER 			ADD CONSTRAINT FK_SBI_OUTPUT_PARAMETER_1 		FOREIGN KEY (BIOBJ_ID) 				REFERENCES SBI_OBJECTS (BIOBJ_ID);
ALTER TABLE SBI_OUTPUT_PARAMETER 			ADD CONSTRAINT FK_SBI_OUTPUT_PARAMETER_2 		FOREIGN KEY (PAR_TYPE_ID) 			REFERENCES SBI_DOMAINS (VALUE_ID);
ALTER TABLE SBI_CROSS_NAVIGATION_PAR 		ADD CONSTRAINT FK_SBI_CROSS_NAVIGATION_PAR_1 	FOREIGN KEY (CN_ID) 				REFERENCES SBI_CROSS_NAVIGATION (ID);
ALTER TABLE SBI_CROSS_NAVIGATION 			ADD CONSTRAINT FK_SBI_CROSS_NAVIGATION_1 		FOREIGN KEY (FROM_DOC_ID) 			REFERENCES SBI_OBJECTS(BIOBJ_ID);
ALTER TABLE SBI_CROSS_NAVIGATION 			ADD CONSTRAINT FK_SBI_CROSS_NAVIGATION_2 		FOREIGN KEY (TO_DOC_ID) 			REFERENCES SBI_OBJECTS(BIOBJ_ID);
ALTER TABLE SBI_ROLES_LAYERS 				ADD CONSTRAINT FK_ID_LAYER 						FOREIGN KEY (ID_LAYER) 				REFERENCES SBI_GEO_LAYERS (LAYER_ID) 	ON DELETE CASCADE;
ALTER TABLE SBI_ROLES_LAYERS 				ADD CONSTRAINT FK_ID_ROLE 						FOREIGN KEY (ID_ROLE) 				REFERENCES SBI_EXT_ROLES (EXT_ROLE_ID) 	ON DELETE CASCADE;
ALTER TABLE SBI_KPI_EXECUTION_FILTER 		ADD CONSTRAINT FK_01_SBI_KPI_EXECUTION_FILTER 		FOREIGN KEY (EXECUTION_ID) 			REFERENCES SBI_KPI_EXECUTION (ID);
ALTER TABLE SBI_KPI_EXECUTION_FILTER 		ADD CONSTRAINT FK_02_SBI_KPI_EXECUTION_FILTER 		FOREIGN KEY (TYPE_ID) 				REFERENCES SBI_DOMAINS (VALUE_ID);
ALTER TABLE SBI_KPI_EXECUTION_FILTER 		ADD CONSTRAINT FK_03_SBI_KPI_EXECUTION_FILTER 		FOREIGN KEY (PLACEHOLDER_ID) 		REFERENCES SBI_KPI_PLACEHOLDER (ID);
ALTER TABLE SBI_KPI_SCORECARD 				ADD CONSTRAINT FK_02_SBI_KPI_SCORECARD 				FOREIGN KEY (CRITERION_ID) 			REFERENCES SBI_DOMAINS (VALUE_ID);
ALTER TABLE SBI_KPI_KPI 					ADD CONSTRAINT FK_01_SBI_KPI_KPI 				FOREIGN KEY (CATEGORY_ID) 			REFERENCES SBI_DOMAINS (VALUE_ID);
ALTER TABLE SBI_KPI_RULE					ADD CONSTRAINT FK_01_SBI_KPI_RULE				FOREIGN KEY (DATASOURCE_ID)			REFERENCES SBI_DATA_SOURCE (DS_ID);
ALTER TABLE SBI_KPI_THRESHOLD 				ADD CONSTRAINT FK_01_SBI_KPI_THRESHOLD 			FOREIGN KEY (TYPE_ID) 				REFERENCES SBI_DOMAINS (VALUE_ID);
ALTER TABLE SBI_KPI_THRESHOLD_VALUE 		ADD CONSTRAINT FK_01_SBI_KPI_THRESHOLD_VALUE 	FOREIGN KEY (SEVERITY_ID) 			REFERENCES SBI_DOMAINS (VALUE_ID);
ALTER TABLE SBI_KPI_THRESHOLD_VALUE			ADD CONSTRAINT FK_02_SBI_KPI_THRESHOLD_VALUE	FOREIGN KEY (THRESHOLD_ID)			REFERENCES SBI_KPI_THRESHOLD (ID);
ALTER TABLE SBI_KPI_RULE_OUTPUT 			ADD CONSTRAINT FK_01_SBI_KPI_RULE_OUTPUT 		FOREIGN KEY (TYPE_ID) 				REFERENCES SBI_DOMAINS (VALUE_ID);
ALTER TABLE SBI_KPI_RULE_OUTPUT 			ADD CONSTRAINT FK_02_SBI_KPI_RULE_OUTPUT 		FOREIGN KEY (RULE_ID,RULE_VERSION) 	REFERENCES SBI_KPI_RULE (ID,VERSION);
ALTER TABLE SBI_KPI_RULE_OUTPUT 			ADD CONSTRAINT FK_03_SBI_KPI_RULE_OUTPUT 		FOREIGN KEY (ALIAS_ID) 				REFERENCES SBI_KPI_ALIAS (ID);
ALTER TABLE SBI_KPI_RULE_OUTPUT 			ADD CONSTRAINT FK_04_SBI_KPI_RULE_OUTPUT 		FOREIGN KEY (CATEGORY_ID) 			REFERENCES SBI_DOMAINS (VALUE_ID);
ALTER TABLE SBI_KPI_RULE_PLACEHOLDER 		ADD CONSTRAINT FK_01_SBI_KPI_RULE_PLACEHOLDER 	FOREIGN KEY (RULE_ID,RULE_VERSION) 	REFERENCES SBI_KPI_RULE (ID,VERSION);
ALTER TABLE SBI_KPI_RULE_PLACEHOLDER 		ADD CONSTRAINT FK_02_SBI_KPI_RULE_PLACEHOLDER 	FOREIGN KEY (PLACEHOLDER_ID) 		REFERENCES SBI_KPI_PLACEHOLDER (ID);
ALTER TABLE SBI_KPI_KPI_RULE_OUTPUT         ADD CONSTRAINT FK_01_SBI_KPI_KPI_RULE_OUTPUT    FOREIGN KEY (KPI_ID,KPI_VERSION)    REFERENCES SBI_KPI_KPI (ID,VERSION);
ALTER TABLE SBI_KPI_KPI_RULE_OUTPUT         ADD CONSTRAINT FK_02_SBI_KPI_KPI_RULE_OUTPUT    FOREIGN KEY (RULE_OUTPUT_ID)        REFERENCES SBI_KPI_RULE_OUTPUT (ID);
ALTER TABLE SBI_KPI_TARGET_VALUE 			ADD CONSTRAINT FK_01_SBI_KPI_TARGET_VALUE 		FOREIGN KEY (TARGET_ID) 			REFERENCES SBI_KPI_TARGET (TARGET_ID);
ALTER TABLE SBI_KPI_TARGET_VALUE 			ADD CONSTRAINT FK_02_SBI_KPI_TARGET_VALUE 		FOREIGN KEY (KPI_ID,KPI_VERSION) 	REFERENCES SBI_KPI_KPI (ID,VERSION);
ALTER TABLE SBI_KPI_TARGET					ADD CONSTRAINT FK_03_SBI_KPI_TARGET 			FOREIGN KEY (CATEGORY_ID) 			REFERENCES SBI_DOMAINS (VALUE_ID);
ALTER TABLE SBI_META_TABLE 					ADD CONSTRAINT FK_SBI_META_TABLE_1 				FOREIGN KEY (SOURCE_ID) 			REFERENCES SBI_META_SOURCE (SOURCE_ID);
ALTER TABLE SBI_META_TABLE_COLUMN 			ADD CONSTRAINT FK_SBI_META_COLUMN_1 			FOREIGN KEY (TABLE_ID) 				REFERENCES SBI_META_TABLE (TABLE_ID);
ALTER TABLE SBI_META_BC 					ADD CONSTRAINT FK_SBI_META_BC_1 				FOREIGN KEY (MODEL_ID) 				REFERENCES SBI_META_MODELS(ID) ON DELETE CASCADE;
ALTER TABLE SBI_META_BC_ATTRIBUTE 			ADD CONSTRAINT FK_SBI_META_BC_ATTRIBUTE_1 		FOREIGN KEY (BC_ID) 				REFERENCES SBI_META_BC(BC_ID) ON DELETE CASCADE;
ALTER TABLE SBI_META_BC_ATTRIBUTE 			ADD CONSTRAINT FK_SBI_META_BC_ATTRIBUTE_2 		FOREIGN KEY (COLUMN_ID) 			REFERENCES SBI_META_TABLE_COLUMN(COLUMN_ID) ON DELETE CASCADE;
ALTER TABLE SBI_META_DS_BC 					ADD CONSTRAINT FK_SBI_META_DS_BC_1 				FOREIGN KEY (DS_ID,VERSION_NUM,ORGANIZATION) REFERENCES SBI_DATA_SET(DS_ID,VERSION_NUM,ORGANIZATION);
ALTER TABLE SBI_META_DS_BC 					ADD CONSTRAINT FK_SBI_META_DS_BC_2 				FOREIGN KEY (BC_ID) 				REFERENCES SBI_META_BC(BC_ID) ON DELETE CASCADE;
ALTER TABLE SBI_META_TABLE_BC 				ADD CONSTRAINT FK_SBI_META_TABLE_BC_1 			FOREIGN KEY (TABLE_ID) 				REFERENCES SBI_META_TABLE(TABLE_ID);
ALTER TABLE SBI_META_TABLE_BC 				ADD CONSTRAINT FK_SBI_META_TABLE_BC_2 			FOREIGN KEY (BC_ID) 				REFERENCES SBI_META_BC(BC_ID) ON DELETE CASCADE;
ALTER TABLE SBI_META_OBJ_DS 				ADD CONSTRAINT FK_SBI_META_OBJ_DS_1 			FOREIGN KEY (DS_ID,VERSION_NUM,ORGANIZATION) REFERENCES SBI_DATA_SET(DS_ID,VERSION_NUM,ORGANIZATION);
ALTER TABLE SBI_META_OBJ_DS 				ADD CONSTRAINT FK_SBI_META_OBJ_DS_2 			FOREIGN KEY (OBJ_ID) 				REFERENCES SBI_OBJECTS(BIOBJ_ID);
ALTER TABLE SBI_META_JOB_SOURCE 			ADD CONSTRAINT FK_SBI_META_JOB_SOURCE_1 		FOREIGN KEY (JOB_ID) 				REFERENCES SBI_META_JOB(JOB_ID);
ALTER TABLE SBI_META_JOB_SOURCE 			ADD CONSTRAINT FK_SBI_META_JOB_SOURCE_2 		FOREIGN KEY (SOURCE_ID) 			REFERENCES SBI_META_SOURCE(SOURCE_ID);
ALTER TABLE SBI_META_JOB_TABLE 				ADD CONSTRAINT FK_SBI_META_JOB_TABLE_1 			FOREIGN KEY (JOB_ID) 				REFERENCES SBI_META_JOB(JOB_ID);
ALTER TABLE SBI_META_JOB_TABLE				ADD CONSTRAINT FK_SBI_META_JOB_TABLE_2 			FOREIGN KEY (TABLE_ID) 				REFERENCES SBI_META_TABLE(TABLE_ID);

ALTER TABLE SBI_ALERT 						ADD CONSTRAINT FK_01_SBI_ALERT 					FOREIGN KEY (LISTENER_ID) 			REFERENCES SBI_ALERT_LISTENER(ID);
ALTER TABLE SBI_ALERT_LOG 					ADD CONSTRAINT FK_01_SBI_ALERT_LOG 				FOREIGN KEY (LISTENER_ID) 			REFERENCES SBI_ALERT_LISTENER(ID);
ALTER TABLE SBI_ALERT_LOG 					ADD CONSTRAINT FK_02_SBI_ALERT_LOG 				FOREIGN KEY (ACTION_ID) 			REFERENCES SBI_ALERT_ACTION(ID);

ALTER TABLE SBI_FUNCTION_INPUT_VARIABLE 	ADD CONSTRAINT FK_FUNCTION_INPUT_VARIABLES_1  	FOREIGN KEY (FUNCTION_UUID, ORGANIZATION)			REFERENCES SBI_CATALOG_FUNCTION(FUNCTION_UUID, ORGANIZATION);
ALTER TABLE SBI_FUNCTION_INPUT_COLUMN 		ADD CONSTRAINT FK_FUNCTION_INPUT_COLUMNS_1  	FOREIGN KEY (FUNCTION_UUID, ORGANIZATION)			REFERENCES SBI_CATALOG_FUNCTION(FUNCTION_UUID, ORGANIZATION);
ALTER TABLE SBI_FUNCTION_OUTPUT_COLUMN 		ADD CONSTRAINT FK_FUNCTION_OUTPUT_COLUMNS_1  	FOREIGN KEY (FUNCTION_UUID, ORGANIZATION)			REFERENCES SBI_CATALOG_FUNCTION(FUNCTION_UUID, ORGANIZATION);

ALTER TABLE SBI_FUNCTIONS_ORGANIZER 		ADD CONSTRAINT FK_SBI_FUNCTIONS_ORGANIZER_1 	FOREIGN KEY (PARENT_FUNCT_ID) 		REFERENCES SBI_FUNCTIONS_ORGANIZER (FUNCT_ID);
ALTER TABLE SBI_OBJ_FUNC_ORGANIZER 			ADD CONSTRAINT FK_SBI_OBJ_FUNC_ORGANIZER_1 		FOREIGN KEY (FUNCT_ID) 				REFERENCES SBI_FUNCTIONS_ORGANIZER (FUNCT_ID);
ALTER TABLE SBI_OBJ_FUNC_ORGANIZER 			ADD CONSTRAINT FK_SBI_OBJ_FUNC_ORGANIZER_2 		FOREIGN KEY (BIOBJ_ID) 				REFERENCES SBI_OBJECTS (BIOBJ_ID) ON DELETE CASCADE;


ALTER TABLE SBI_WHATIF_WORKFLOW 				ADD CONSTRAINT FK_SBI_MODEL_WORKFLOW			FOREIGN KEY (MODEL_ID) 			REFERENCES SBI_ARTIFACTS(ID)					ON DELETE CASCADE;
ALTER TABLE SBI_WHATIF_WORKFLOW 				ADD CONSTRAINT FK_SBI_USER_WORKFLOW			FOREIGN KEY (USER_ID) 				REFERENCES SBI_USER(ID) ON DELETE CASCADE;


CREATE UNIQUE INDEX SBI_FED_DEF_NAME_UNIQUE ON SBI_FEDERATION_DEFINITION(NAME ASC, ORGANIZATION ASC);
CREATE UNIQUE INDEX SBI_FED_DEF_LABEL_UNIQUE ON SBI_FEDERATION_DEFINITION(LABEL ASC, ORGANIZATION ASC);
CREATE UNIQUE INDEX IDX_UNQ_SBI_KPI_VALUE ON SBI_KPI_VALUE(KPI_ID,KPI_VERSION,LOGICAL_KEY,THE_DAY,THE_WEEK,THE_MONTH,THE_QUARTER,THE_YEAR,TIME_RUN);

CREATE INDEX IDX_SBI_ACCESSIB_PREF_SBI_USER 		ON SBI_ACCESSIBILITY_PREFERENCES (USER_ID);
ALTER TABLE SBI_ACCESSIBILITY_PREFERENCES ADD CONSTRAINT FK_SBI_ACCESSIB_PREF_SBI_USER FOREIGN KEY (USER_ID) REFERENCES SBI_USER (ID) ON DELETE CASCADE;

ALTER TABLE SBI_META_MODELS	ADD CONSTRAINT FK_META_MODELS_DS_ID	 FOREIGN KEY (DATA_SOURCE_ID) 	REFERENCES SBI_DATA_SOURCE(DS_ID);

ALTER TABLE SBI_DOSSIER_ACTIVITY ADD CONSTRAINT FK_SBI_PROGRESS_THREAD	FOREIGN KEY (PROGRESS) 	REFERENCES SBI_PROGRESS_THREAD(PROGRESS_THREAD_ID);
ALTER TABLE SBI_DOSSIER_ACTIVITY ADD CONSTRAINT FK_SBI_OBJECTS FOREIGN KEY  (DOCUMENT_ID) REFERENCES SBI_OBJECTS (BIOBJ_ID);

ALTER TABLE SBI_ATTRIBUTE ADD CONSTRAINT FK_LOV FOREIGN KEY (LOV_ID) REFERENCES SBI_LOV(LOV_ID);

ALTER TABLE SBI_METAMODEL_PAR ADD CONSTRAINT SBI_METAMODEL_PAR_1 FOREIGN KEY (METAMODEL_ID) REFERENCES SBI_META_MODELS (ID);
ALTER TABLE SBI_METAMODEL_PAR ADD CONSTRAINT SBI_METAMODEL_PAR_2 FOREIGN KEY (PAR_ID) REFERENCES SBI_PARAMETERS (PAR_ID);

ALTER TABLE SBI_METAMODEL_PARUSE ADD CONSTRAINT SBI_METAMODEL_PARUSE_1 FOREIGN KEY (METAMODEL_PAR_ID) REFERENCES SBI_METAMODEL_PAR (METAMODEL_PAR_ID);
ALTER TABLE SBI_METAMODEL_PARUSE ADD CONSTRAINT SBI_METAMODEL_PARUSE_2 FOREIGN KEY (METAMODEL_PAR_FATHER_ID) REFERENCES SBI_METAMODEL_PAR (METAMODEL_PAR_ID);
ALTER TABLE SBI_METAMODEL_PARUSE ADD CONSTRAINT SBI_METAMODEL_PARUSE_3 FOREIGN KEY (USE_ID) REFERENCES SBI_PARUSE (USE_ID);

ALTER TABLE SBI_METAMODEL_PARVIEW ADD CONSTRAINT FK_SBI_METAMODEL_PARVIEW_1 FOREIGN KEY ( METAMODEL_PAR_ID ) REFERENCES SBI_METAMODEL_PAR ( METAMODEL_PAR_ID );
ALTER TABLE SBI_METAMODEL_PARVIEW ADD CONSTRAINT FK_SBI_METAMODEL_PARVIEW_2 FOREIGN KEY ( METAMODEL_PAR_FATHER_ID ) REFERENCES SBI_METAMODEL_PAR ( METAMODEL_PAR_ID );

ALTER TABLE SBI_DOSSIER_ACTIVITY ADD DOC BLOB NULL; 
ALTER TABLE SBI_DOSSIER_ACTIVITY ADD CONFIG VARCHAR(4000) NULL;

